@@ -17,7 +17,7 @@
 
 #include <gz/transport.hh>
 #include <gz/math.hh>
-#include <ignition/msgs.hh>
+#include <gz/msgs.hh>
 #include <gz/common/Time.hh>
 
 #include <iostream>
@@ -54,15 +54,15 @@ int main(int _argc, char **_argv)
   // Read the terminal statements to figure out what each node.Request
   // call accomplishes.
   std::cout << "Spawning a blue sphere with lifetime 2s\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   gz::msgs::Set(markerMsg.mutable_pose(),
                       gz::math::Pose3d(2, 2, 0, 0, 0, 0));
   node.Request("/marker", markerMsg);
   std::cout << "Sleeping for 2 seconds\n";
-  gz::common::Time::Sleep(gz::common::Time(2));
+  IGN_SLEEP_S(2);
 
   std::cout << "Spawning a black sphere at the origin with no lifetime\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(1);
   gz::msgs::Set(markerMsg.mutable_pose(),
                       gz::math::Pose3d::Zero);
@@ -72,13 +72,13 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Moving the sphere to x=0, y=1, z=1\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   gz::msgs::Set(markerMsg.mutable_pose(),
                       gz::math::Pose3d(0, 1, 1, 0, 0, 0));
   node.Request("/marker", markerMsg);
 
   std::cout << "Shrinking the sphere\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   gz::msgs::Set(markerMsg.mutable_scale(),
                     gz::math::Vector3d(0.2, 0.2, 0.2));
   node.Request("/marker", markerMsg);
@@ -90,7 +90,7 @@ int main(int _argc, char **_argv)
   markerMsg.mutable_material()->mutable_diffuse()->set_r(1);
   markerMsg.mutable_material()->mutable_diffuse()->set_g(0);
   markerMsg.mutable_material()->mutable_diffuse()->set_b(0);
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   node.Request("/marker", markerMsg);
 
   std::cout << "Adding a green box\n";
@@ -100,7 +100,7 @@ int main(int _argc, char **_argv)
   markerMsg.mutable_material()->mutable_diffuse()->set_r(0);
   markerMsg.mutable_material()->mutable_diffuse()->set_g(1);
   markerMsg.mutable_material()->mutable_diffuse()->set_b(0);
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(2);
   markerMsg.set_action(gz::msgs::Marker::ADD_MODIFY);
   markerMsg.set_type(gz::msgs::Marker::BOX);
@@ -111,12 +111,12 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Changing the green box to a cylinder\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_type(gz::msgs::Marker::CYLINDER);
   node.Request("/marker", markerMsg);
 
   std::cout << "Connecting the sphere and cylinder with a line\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(3);
   gz::msgs::Set(markerMsg.mutable_pose(),
                     gz::math::Pose3d(0, 0, 0, 0, 0, 0));
@@ -129,7 +129,7 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Adding a square around the origin\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(4);
   markerMsg.set_action(gz::msgs::Marker::ADD_MODIFY);
   markerMsg.set_type(gz::msgs::Marker::LINE_STRIP);
@@ -146,7 +146,7 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Adding 100 points inside the square\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(5);
   markerMsg.set_action(gz::msgs::Marker::ADD_MODIFY);
   markerMsg.set_type(gz::msgs::Marker::POINTS);
@@ -162,7 +162,7 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Adding a semi-circular triangle fan\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(6);
   markerMsg.set_action(gz::msgs::Marker::ADD_MODIFY);
   markerMsg.set_type(gz::msgs::Marker::TRIANGLE_FAN);
@@ -180,7 +180,7 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Adding two triangles using a triangle list\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(7);
   markerMsg.set_action(gz::msgs::Marker::ADD_MODIFY);
   markerMsg.set_type(gz::msgs::Marker::TRIANGLE_LIST);
@@ -204,7 +204,7 @@ int main(int _argc, char **_argv)
   node.Request("/marker", markerMsg);
 
   std::cout << "Adding a rectangular triangle strip\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_id(8);
   markerMsg.set_action(gz::msgs::Marker::ADD_MODIFY);
   markerMsg.set_type(gz::msgs::Marker::TRIANGLE_STRIP);
@@ -227,7 +227,7 @@ int main(int _argc, char **_argv)
 
   node.Request("/marker", markerMsg);
   std::cout << "Adding multiple markers via /marker_array\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
 
   gz::msgs::Marker_V markerMsgs;
   gz::msgs::Boolean res;
@@ -308,7 +308,7 @@ int main(int _argc, char **_argv)
   node.Request("/marker_array", markerMsgs, timeout, res, result);
 
   std::cout << "Deleting all the markers\n";
-  gz::common::Time::Sleep(gz::common::Time(4));
+  IGN_SLEEP_S(4);
   markerMsg.set_action(gz::msgs::Marker::DELETE_ALL);
   node.Request("/marker", markerMsg);
 }
