@@ -15,33 +15,33 @@
  *
 */
 
-#include <ignition/msgs/actor.pb.h>
-#include <ignition/msgs/atmosphere.pb.h>
-#include <ignition/msgs/axis_aligned_box.pb.h>
-#include <ignition/msgs/boxgeom.pb.h>
-#include <ignition/msgs/capsulegeom.pb.h>
-#include <ignition/msgs/cylindergeom.pb.h>
-#include <ignition/msgs/ellipsoidgeom.pb.h>
-#include <ignition/msgs/entity.pb.h>
-#include <ignition/msgs/geometry.pb.h>
-#include <ignition/msgs/gps_sensor.pb.h>
-#include <ignition/msgs/gui.pb.h>
-#include <ignition/msgs/heightmapgeom.pb.h>
-#include <ignition/msgs/imu_sensor.pb.h>
-#include <ignition/msgs/lidar_sensor.pb.h>
-#include <ignition/msgs/light.pb.h>
-#include <ignition/msgs/material.pb.h>
-#include <ignition/msgs/planegeom.pb.h>
-#include <ignition/msgs/plugin.pb.h>
-#include <ignition/msgs/spheregeom.pb.h>
-#include <ignition/msgs/Utility.hh>
+#include <gz/msgs/actor.pb.h>
+#include <gz/msgs/atmosphere.pb.h>
+#include <gz/msgs/axis_aligned_box.pb.h>
+#include <gz/msgs/boxgeom.pb.h>
+#include <gz/msgs/capsulegeom.pb.h>
+#include <gz/msgs/cylindergeom.pb.h>
+#include <gz/msgs/ellipsoidgeom.pb.h>
+#include <gz/msgs/entity.pb.h>
+#include <gz/msgs/geometry.pb.h>
+#include <gz/msgs/gps_sensor.pb.h>
+#include <gz/msgs/gui.pb.h>
+#include <gz/msgs/heightmapgeom.pb.h>
+#include <gz/msgs/imu_sensor.pb.h>
+#include <gz/msgs/lidar_sensor.pb.h>
+#include <gz/msgs/light.pb.h>
+#include <gz/msgs/material.pb.h>
+#include <gz/msgs/planegeom.pb.h>
+#include <gz/msgs/plugin.pb.h>
+#include <gz/msgs/spheregeom.pb.h>
+#include <gz/msgs/Utility.hh>
 
-#include <ignition/math/Angle.hh>
-#include <ignition/math/AxisAlignedBox.hh>
-#include <ignition/math/Helpers.hh>
-#include <ignition/math/Temperature.hh>
+#include <gz/math/Angle.hh>
+#include <gz/math/AxisAlignedBox.hh>
+#include <gz/math/Helpers.hh>
+#include <gz/math/Temperature.hh>
 
-#include <ignition/common/Console.hh>
+#include <gz/common/Console.hh>
 
 #include <sdf/Actor.hh>
 #include <sdf/Atmosphere.hh>
@@ -70,16 +70,16 @@
 #include <algorithm>
 #include <string>
 
-#include "ignition/gazebo/Conversions.hh"
-#include "ignition/gazebo/Export.hh"
-#include "ignition/gazebo/Util.hh"
+#include "gz/sim/Conversions.hh"
+#include "gz/sim/Export.hh"
+#include "gz/sim/Util.hh"
 
-using namespace ignition;
+using namespace gz;
 
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Entity_Type ignition::gazebo::convert(const std::string &_in)
+msgs::Entity_Type gazebo::convert(const std::string &_in)
 {
   msgs::Entity_Type out = msgs::Entity_Type_NONE;
 
@@ -117,7 +117,7 @@ msgs::Entity_Type ignition::gazebo::convert(const std::string &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::Pose3d ignition::gazebo::convert(const msgs::Pose &_in)
+math::Pose3d gazebo::convert(const msgs::Pose &_in)
 {
   math::Pose3d out(_in.position().x(),
                    _in.position().y(),
@@ -134,7 +134,7 @@ math::Pose3d ignition::gazebo::convert(const msgs::Pose &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Collision ignition::gazebo::convert(const sdf::Collision &_in)
+msgs::Collision gazebo::convert(const sdf::Collision &_in)
 {
   msgs::Collision out;
   out.set_name(_in.Name());
@@ -147,7 +147,7 @@ msgs::Collision ignition::gazebo::convert(const sdf::Collision &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Collision ignition::gazebo::convert(const msgs::Collision &_in)
+sdf::Collision gazebo::convert(const msgs::Collision &_in)
 {
   sdf::Collision out;
   out.SetName(_in.name());
@@ -159,7 +159,7 @@ sdf::Collision ignition::gazebo::convert(const msgs::Collision &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Geometry ignition::gazebo::convert(const sdf::Geometry &_in)
+msgs::Geometry gazebo::convert(const sdf::Geometry &_in)
 {
   msgs::Geometry out;
   if (_in.Type() == sdf::GeometryType::BOX && _in.BoxShape())
@@ -268,7 +268,7 @@ msgs::Geometry ignition::gazebo::convert(const sdf::Geometry &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Geometry ignition::gazebo::convert(const msgs::Geometry &_in)
+sdf::Geometry gazebo::convert(const msgs::Geometry &_in)
 {
   sdf::Geometry out;
   if (_in.type() == msgs::Geometry::BOX && _in.has_box())
@@ -405,7 +405,7 @@ sdf::Geometry ignition::gazebo::convert(const msgs::Geometry &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Material ignition::gazebo::convert(const sdf::Material &_in)
+msgs::Material gazebo::convert(const sdf::Material &_in)
 {
   msgs::Material out;
   msgs::Set(out.mutable_ambient(), _in.Ambient());
@@ -464,7 +464,7 @@ msgs::Material ignition::gazebo::convert(const sdf::Material &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Material ignition::gazebo::convert(const msgs::Material &_in)
+sdf::Material gazebo::convert(const msgs::Material &_in)
 {
   sdf::Material out;
   out.SetAmbient(msgs::Convert(_in.ambient()));
@@ -507,7 +507,7 @@ sdf::Material ignition::gazebo::convert(const msgs::Material &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Actor ignition::gazebo::convert(const sdf::Actor &_in)
+msgs::Actor gazebo::convert(const sdf::Actor &_in)
 {
   msgs::Actor out;
   out.mutable_entity()->set_name(_in.Name());
@@ -547,7 +547,7 @@ msgs::Actor ignition::gazebo::convert(const sdf::Actor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Actor ignition::gazebo::convert(const msgs::Actor &_in)
+sdf::Actor gazebo::convert(const msgs::Actor &_in)
 {
   sdf::Actor out;
   out.SetName(_in.entity().name());
@@ -590,7 +590,7 @@ sdf::Actor ignition::gazebo::convert(const msgs::Actor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Light ignition::gazebo::convert(const sdf::Light &_in)
+msgs::Light gazebo::convert(const sdf::Light &_in)
 {
   msgs::Light out;
   out.set_name(_in.Name());
@@ -638,7 +638,7 @@ msgs::Light ignition::gazebo::convert(const sdf::Light &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Light ignition::gazebo::convert(const msgs::Light &_in)
+sdf::Light gazebo::convert(const msgs::Light &_in)
 {
   sdf::Light out;
   out.SetName(_in.name());
@@ -704,7 +704,7 @@ sdf::Light ignition::gazebo::convert(const msgs::Light &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::GUI ignition::gazebo::convert(const sdf::Gui &_in)
+msgs::GUI gazebo::convert(const sdf::Gui &_in)
 {
   msgs::GUI out;
 
@@ -728,12 +728,12 @@ msgs::GUI ignition::gazebo::convert(const sdf::Gui &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Time ignition::gazebo::convert(
+msgs::Time gazebo::convert(
     const std::chrono::steady_clock::duration &_in)
 {
   msgs::Time out;
 
-  auto secNsec = ignition::math::durationToSecNsec(_in);
+  auto secNsec = math::durationToSecNsec(_in);
 
   out.set_sec(secNsec.first);
   out.set_nsec(secNsec.second);
@@ -744,7 +744,7 @@ msgs::Time ignition::gazebo::convert(
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-std::chrono::steady_clock::duration ignition::gazebo::convert(
+std::chrono::steady_clock::duration gazebo::convert(
     const msgs::Time &_in)
 {
   return std::chrono::seconds(_in.sec()) + std::chrono::nanoseconds(_in.nsec());
@@ -753,7 +753,7 @@ std::chrono::steady_clock::duration ignition::gazebo::convert(
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Inertial ignition::gazebo::convert(const math::Inertiald &_in)
+msgs::Inertial gazebo::convert(const math::Inertiald &_in)
 {
   msgs::Inertial out;
   msgs::Set(out.mutable_pose(), _in.Pose());
@@ -770,7 +770,7 @@ msgs::Inertial ignition::gazebo::convert(const math::Inertiald &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::Inertiald ignition::gazebo::convert(const msgs::Inertial &_in)
+math::Inertiald gazebo::convert(const msgs::Inertial &_in)
 {
   math::MassMatrix3d massMatrix;
   massMatrix.SetMass(_in.mass());
@@ -790,7 +790,7 @@ math::Inertiald ignition::gazebo::convert(const msgs::Inertial &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Axis ignition::gazebo::convert(const sdf::JointAxis &_in)
+msgs::Axis gazebo::convert(const sdf::JointAxis &_in)
 {
   msgs::Axis out;
   msgs::Set(out.mutable_xyz(), _in.Xyz());
@@ -820,7 +820,7 @@ msgs::Axis ignition::gazebo::convert(const sdf::JointAxis &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::JointAxis ignition::gazebo::convert(const msgs::Axis &_in)
+sdf::JointAxis gazebo::convert(const msgs::Axis &_in)
 {
   sdf::JointAxis out;
   sdf::Errors errors = out.SetXyz(msgs::Convert(_in.xyz()));
@@ -840,7 +840,7 @@ sdf::JointAxis ignition::gazebo::convert(const msgs::Axis &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Scene ignition::gazebo::convert(const sdf::Scene &_in)
+msgs::Scene gazebo::convert(const sdf::Scene &_in)
 {
   msgs::Scene out;
   // todo(anyone) add Name to sdf::Scene?
@@ -863,6 +863,13 @@ msgs::Scene ignition::gazebo::convert(const sdf::Scene &_in)
     skyMsg->set_mean_cloud_size(_in.Sky()->CloudMeanSize());
     msgs::Set(skyMsg->mutable_cloud_ambient(),
         _in.Sky()->CloudAmbient());
+
+    if (!_in.Sky()->CubemapUri().empty())
+    {
+      auto header = skyMsg->mutable_header()->add_data();
+      header->set_key("cubemap_uri");
+      header->add_value(_in.Sky()->CubemapUri());
+    }
   }
 
   return out;
@@ -871,7 +878,7 @@ msgs::Scene ignition::gazebo::convert(const sdf::Scene &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Scene ignition::gazebo::convert(const msgs::Scene &_in)
+sdf::Scene gazebo::convert(const msgs::Scene &_in)
 {
   sdf::Scene out;
   // todo(anyone) add SetName to sdf::Scene?
@@ -893,6 +900,16 @@ sdf::Scene ignition::gazebo::convert(const msgs::Scene &_in)
     sky.SetCloudHumidity(_in.sky().humidity());
     sky.SetCloudMeanSize(_in.sky().mean_cloud_size());
     sky.SetCloudAmbient(msgs::Convert(_in.sky().cloud_ambient()));
+
+    for (int i = 0; i < _in.sky().header().data_size(); ++i)
+    {
+      auto data = _in.sky().header().data(i);
+      if (data.key() == "cubemap_uri" && data.value_size() > 0)
+      {
+        sky.SetCubemapUri(data.value(0));
+      }
+    }
+
     out.SetSky(sky);
   }
   return out;
@@ -901,7 +918,7 @@ sdf::Scene ignition::gazebo::convert(const msgs::Scene &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Atmosphere ignition::gazebo::convert(const sdf::Atmosphere &_in)
+msgs::Atmosphere gazebo::convert(const sdf::Atmosphere &_in)
 {
   msgs::Atmosphere out;
   out.set_temperature(_in.Temperature().Kelvin());
@@ -919,7 +936,7 @@ msgs::Atmosphere ignition::gazebo::convert(const sdf::Atmosphere &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Atmosphere ignition::gazebo::convert(const msgs::Atmosphere &_in)
+sdf::Atmosphere gazebo::convert(const msgs::Atmosphere &_in)
 {
   sdf::Atmosphere out;
   out.SetTemperature(math::Temperature(_in.temperature()));
@@ -935,16 +952,16 @@ sdf::Atmosphere ignition::gazebo::convert(const msgs::Atmosphere &_in)
 }
 
 //////////////////////////////////////////////////
-void ignition::gazebo::set(msgs::Time *_msg,
+void gazebo::set(msgs::Time *_msg,
     const std::chrono::steady_clock::duration &_in)
 {
-  auto secNsec = ignition::math::durationToSecNsec(_in);
+  auto secNsec = math::durationToSecNsec(_in);
   _msg->set_sec(secNsec.first);
   _msg->set_nsec(secNsec.second);
 }
 
 //////////////////////////////////////////////////
-void ignition::gazebo::set(msgs::WorldStatistics *_msg,
+void gazebo::set(msgs::WorldStatistics *_msg,
     const gazebo::UpdateInfo &_in)
 {
   set(_msg->mutable_sim_time(), _in.simTime);
@@ -957,7 +974,7 @@ void ignition::gazebo::set(msgs::WorldStatistics *_msg,
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Physics ignition::gazebo::convert(const sdf::Physics &_in)
+msgs::Physics gazebo::convert(const sdf::Physics &_in)
 {
   msgs::Physics out;
   out.set_max_step_size(_in.MaxStepSize());
@@ -968,7 +985,7 @@ msgs::Physics ignition::gazebo::convert(const sdf::Physics &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Physics ignition::gazebo::convert(const msgs::Physics &_in)
+sdf::Physics gazebo::convert(const msgs::Physics &_in)
 {
   sdf::Physics out;
   out.SetRealTimeFactor(_in.real_time_factor());
@@ -977,7 +994,7 @@ sdf::Physics ignition::gazebo::convert(const msgs::Physics &_in)
 }
 
 //////////////////////////////////////////////////
-void ignition::gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
+void gazebo::set(msgs::SensorNoise *_msg, const sdf::Noise &_sdf)
 {
   switch (_sdf.Type())
   {
@@ -1044,7 +1061,7 @@ sdf::LightType ignition::gazebo::convert(const std::string &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Noise ignition::gazebo::convert(const msgs::SensorNoise &_in)
+sdf::Noise gazebo::convert(const msgs::SensorNoise &_in)
 {
   sdf::Noise out;
 
@@ -1077,7 +1094,7 @@ sdf::Noise ignition::gazebo::convert(const msgs::SensorNoise &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
+msgs::Sensor gazebo::convert(const sdf::Sensor &_in)
 {
   msgs::Sensor out;
   out.set_name(_in.Name());
@@ -1093,17 +1110,17 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
       msgs::MagnetometerSensor *sensor = out.mutable_magnetometer();
       if (_in.MagnetometerSensor()->XNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_x_noise(),
+        gazebo::set(sensor->mutable_x_noise(),
             _in.MagnetometerSensor()->XNoise());
       }
       if (_in.MagnetometerSensor()->YNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_y_noise(),
+        gazebo::set(sensor->mutable_y_noise(),
             _in.MagnetometerSensor()->YNoise());
       }
       if (_in.MagnetometerSensor()->ZNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_z_noise(),
+        gazebo::set(sensor->mutable_z_noise(),
             _in.MagnetometerSensor()->ZNoise());
       }
     }
@@ -1191,13 +1208,13 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
       if (_in.AltimeterSensor()->VerticalPositionNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_vertical_position_noise(),
+        gazebo::set(sensor->mutable_vertical_position_noise(),
             _in.AltimeterSensor()->VerticalPositionNoise());
       }
       if (_in.AltimeterSensor()->VerticalVelocityNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_vertical_velocity_noise(),
+        gazebo::set(sensor->mutable_vertical_velocity_noise(),
             _in.AltimeterSensor()->VerticalVelocityNoise());
       }
     }
@@ -1216,7 +1233,7 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
       if (_in.AirPressureSensor()->PressureNoise().Type()
           != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_pressure_noise(),
+        gazebo::set(sensor->mutable_pressure_noise(),
             _in.AirPressureSensor()->PressureNoise());
       }
       sensor->set_reference_altitude(
@@ -1237,38 +1254,38 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 
       if (sdfImu->LinearAccelerationXNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_x_noise(),
             sdfImu->LinearAccelerationXNoise());
       }
       if (sdfImu->LinearAccelerationYNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_y_noise(),
             sdfImu->LinearAccelerationYNoise());
       }
       if (sdfImu->LinearAccelerationZNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_linear_acceleration()->mutable_z_noise(),
             sdfImu->LinearAccelerationZNoise());
       }
 
       if (sdfImu->AngularVelocityXNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_angular_velocity()->mutable_x_noise(),
             sdfImu->AngularVelocityXNoise());
       }
       if (sdfImu->AngularVelocityYNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_angular_velocity()->mutable_y_noise(),
             sdfImu->AngularVelocityYNoise());
       }
       if (sdfImu->AngularVelocityZNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(
+        gazebo::set(
             sensor->mutable_angular_velocity()->mutable_z_noise(),
             sdfImu->AngularVelocityZNoise());
       }
@@ -1302,7 +1319,7 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 
       if (sdfLidar->LidarNoise().Type() != sdf::NoiseType::NONE)
       {
-        ignition::gazebo::set(sensor->mutable_noise(), sdfLidar->LidarNoise());
+        gazebo::set(sensor->mutable_noise(), sdfLidar->LidarNoise());
       }
       sensor->set_horizontal_samples(sdfLidar->HorizontalScanSamples());
       sensor->set_horizontal_resolution(sdfLidar->HorizontalScanResolution());
@@ -1332,7 +1349,7 @@ msgs::Sensor ignition::gazebo::convert(const sdf::Sensor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
+sdf::Sensor gazebo::convert(const msgs::Sensor &_in)
 {
   sdf::Sensor out;
   out.SetName(_in.name());
@@ -1349,17 +1366,17 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.magnetometer().has_x_noise())
       {
-        sensor.SetXNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetXNoise(gazebo::convert<sdf::Noise>(
               _in.magnetometer().x_noise()));
       }
       if (_in.magnetometer().has_y_noise())
       {
-        sensor.SetYNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetYNoise(gazebo::convert<sdf::Noise>(
               _in.magnetometer().y_noise()));
       }
       if (_in.magnetometer().has_z_noise())
       {
-        sensor.SetZNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetZNoise(gazebo::convert<sdf::Noise>(
               _in.magnetometer().z_noise()));
       }
     }
@@ -1414,13 +1431,13 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.altimeter().has_vertical_position_noise())
       {
-        sensor.SetVerticalPositionNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetVerticalPositionNoise(gazebo::convert<sdf::Noise>(
               _in.altimeter().vertical_position_noise()));
       }
 
       if (_in.altimeter().has_vertical_velocity_noise())
       {
-        sensor.SetVerticalVelocityNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetVerticalVelocityNoise(gazebo::convert<sdf::Noise>(
               _in.altimeter().vertical_velocity_noise()));
       }
     }
@@ -1439,7 +1456,7 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
     {
       if (_in.air_pressure().has_pressure_noise())
       {
-        sensor.SetPressureNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetPressureNoise(gazebo::convert<sdf::Noise>(
               _in.air_pressure().pressure_noise()));
       }
 
@@ -1463,19 +1480,19 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
         if (_in.imu().linear_acceleration().has_x_noise())
         {
           sensor.SetLinearAccelerationXNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().x_noise()));
         }
         if (_in.imu().linear_acceleration().has_y_noise())
         {
           sensor.SetLinearAccelerationYNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().y_noise()));
         }
         if (_in.imu().linear_acceleration().has_z_noise())
         {
           sensor.SetLinearAccelerationZNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().linear_acceleration().z_noise()));
         }
       }
@@ -1485,19 +1502,19 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
         if (_in.imu().angular_velocity().has_x_noise())
         {
           sensor.SetAngularVelocityXNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().x_noise()));
         }
         if (_in.imu().angular_velocity().has_y_noise())
         {
           sensor.SetAngularVelocityYNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().y_noise()));
         }
         if (_in.imu().angular_velocity().has_z_noise())
         {
           sensor.SetAngularVelocityZNoise(
-              ignition::gazebo::convert<sdf::Noise>(
+              gazebo::convert<sdf::Noise>(
                 _in.imu().angular_velocity().z_noise()));
         }
       }
@@ -1554,7 +1571,7 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
 
       if (_in.lidar().has_noise())
       {
-        sensor.SetLidarNoise(ignition::gazebo::convert<sdf::Noise>(
+        sensor.SetLidarNoise(gazebo::convert<sdf::Noise>(
               _in.lidar().noise()));
       }
     }
@@ -1572,7 +1589,7 @@ sdf::Sensor ignition::gazebo::convert(const msgs::Sensor &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::WorldStatistics ignition::gazebo::convert(const gazebo::UpdateInfo &_in)
+msgs::WorldStatistics gazebo::convert(const gazebo::UpdateInfo &_in)
 {
   msgs::WorldStatistics out;
   set(&out, _in);
@@ -1582,7 +1599,7 @@ msgs::WorldStatistics ignition::gazebo::convert(const gazebo::UpdateInfo &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-gazebo::UpdateInfo ignition::gazebo::convert(const msgs::WorldStatistics &_in)
+gazebo::UpdateInfo gazebo::convert(const msgs::WorldStatistics &_in)
 {
   gazebo::UpdateInfo out;
   out.iterations = _in.iterations();
@@ -1596,7 +1613,7 @@ gazebo::UpdateInfo ignition::gazebo::convert(const msgs::WorldStatistics &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-msgs::AxisAlignedBox ignition::gazebo::convert(const math::AxisAlignedBox &_in)
+msgs::AxisAlignedBox gazebo::convert(const math::AxisAlignedBox &_in)
 {
   msgs::AxisAlignedBox out;
   msgs::Set(out.mutable_min_corner(), _in.Min());
@@ -1607,7 +1624,7 @@ msgs::AxisAlignedBox ignition::gazebo::convert(const math::AxisAlignedBox &_in)
 //////////////////////////////////////////////////
 template<>
 IGNITION_GAZEBO_VISIBLE
-math::AxisAlignedBox ignition::gazebo::convert(const msgs::AxisAlignedBox &_in)
+math::AxisAlignedBox gazebo::convert(const msgs::AxisAlignedBox &_in)
 {
   math::AxisAlignedBox out;
   out.Min() = msgs::Convert(_in.min_corner());
