@@ -17,30 +17,38 @@
 
 #include "EntityTree.hh"
 
+#include <algorithm>
 #include <iostream>
+#include <mutex>
+#include <set>
+#include <string>
 #include <vector>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/gui/Application.hh>
-#include <ignition/gui/MainWindow.hh>
-#include <ignition/plugin/Register.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/MeshManager.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/gui/Application.hh>
+#include <gz/gui/GuiEvents.hh>
+#include <gz/gui/MainWindow.hh>
+#include <gz/plugin/Register.hh>
 
-#include "ignition/gazebo/components/Actor.hh"
-#include "ignition/gazebo/components/Collision.hh"
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/Level.hh"
-#include "ignition/gazebo/components/Light.hh"
-#include "ignition/gazebo/components/Link.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/Performer.hh"
-#include "ignition/gazebo/components/Sensor.hh"
-#include "ignition/gazebo/components/Visual.hh"
-#include "ignition/gazebo/components/World.hh"
-#include "ignition/gazebo/EntityComponentManager.hh"
-#include "ignition/gazebo/gui/GuiEvents.hh"
+#include "gz/sim/components/Actor.hh"
+#include "gz/sim/components/Collision.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/Level.hh"
+#include "gz/sim/components/Light.hh"
+#include "gz/sim/components/Link.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/Performer.hh"
+#include "gz/sim/components/Sensor.hh"
+#include "gz/sim/components/Visual.hh"
+#include "gz/sim/components/World.hh"
+#include "gz/sim/gui/GuiEvents.hh"
+
+#include "gz/sim/EntityComponentManager.hh"
+#include "gz/sim/Primitives.hh"
 
 namespace ignition::gazebo
 {
@@ -54,11 +62,21 @@ namespace ignition::gazebo
 
     /// \brief World entity
     public: Entity worldEntity{kNullEntity};
+
+    /// \brief List of new entities from a gui event
+    public: std::set<Entity> newEntities;
+
+    /// \brief List of removed entities from a gui event
+    public: std::set<Entity> removedEntities;
+
+    /// \brief Mutex to protect gui event and system upate call race conditions
+    /// for newEntities and removedEntities
+    public: std::mutex newRemovedEntityMutex;
   };
 }
 
 using namespace ignition;
-using namespace gazebo;
+using namespace ignition::gazebo;
 
 //////////////////////////////////////////////////
 QString entityType(Entity _entity,
@@ -100,16 +118,23 @@ QString entityType(Entity _entity,
 /////////////////////////////////////////////////
 TreeModel::TreeModel() : QStandardItemModel()
 {
+  qRegisterMetaType<Entity>("Entity");
 }
 
 /////////////////////////////////////////////////
-void TreeModel::AddEntity(unsigned int _entity, const QString &_entityName,
-    unsigned int _parentEntity, const QString &_type)
+void TreeModel::AddEntity(Entity _entity, const QString &_entityName,
+    Entity _parentEntity, const QString &_type)
 {
   IGN_PROFILE_THREAD_NAME("Qt thread");
   IGN_PROFILE("TreeModel::AddEntity");
   QStandardItem *parentItem{nullptr};
 
+  // check if entity has already been added or not.
+  // This could happen because we get new and removed entity updates from both
+  // the ECM and GUI events.
+  if (this->entityItems.find(_entity) != this->entityItems.end())
+    return;
+
   // Root
   if (_parentEntity == kNullEntity)
   {
@@ -132,13 +157,6 @@ void TreeModel::AddEntity(unsigned int _entity, const QString &_entityName,
     return;
   }
 
-  if (this->entityItems.find(_entity) != this->entityItems.end())
-  {
-    ignwarn << "Internal error: Trying to create item for entity [" << _entity
-            << "], but entity already has an item." << std::endl;
-    return;
-  }
-
   // New entity item
   auto entityItem = new QStandardItem(_entityName);
   entityItem->setData(_entityName, this->roleNames().key("entityName"));
@@ -165,7 +183,7 @@ void TreeModel::AddEntity(unsigned int _entity, const QString &_entityName,
 }
 
 /////////////////////////////////////////////////
-void TreeModel::RemoveEntity(unsigned int _entity)
+void TreeModel::RemoveEntity(Entity _entity)
 {
   IGN_PROFILE("TreeModel::RemoveEntity");
   QStandardItem *item{nullptr};
@@ -247,7 +265,7 @@ QString TreeModel::ScopedName(const QModelIndex &_index) const
 }
 
 /////////////////////////////////////////////////
-unsigned int TreeModel::EntityId(const QModelIndex &_index) const
+Entity TreeModel::EntityId(const QModelIndex &_index) const
 {
   Entity entity{kNullEntity};
   QStandardItem *item = this->itemFromIndex(_index);
@@ -274,7 +292,7 @@ EntityTree::EntityTree()
   : GuiSystem(), dataPtr(std::make_unique<EntityTreePrivate>())
 {
   // Connect model
-  ignition::gui::App()->Engine()->rootContext()->setContextProperty(
+  gz::gui::App()->Engine()->rootContext()->setContextProperty(
      "EntityTreeModel", &this->dataPtr->treeModel);
 }
 
@@ -287,8 +305,8 @@ void EntityTree::LoadConfig(const tinyxml2::XMLElement *)
   if (this->title.empty())
     this->title = "Entity tree";
 
-  ignition::gui::App()->findChild<
-      ignition::gui::MainWindow *>()->installEventFilter(this);
+  gz::gui::App()->findChild<
+      gz::gui::MainWindow *>()->installEventFilter(this);
 }
 
 //////////////////////////////////////////////////
@@ -329,9 +347,9 @@ void EntityTree::Update(const UpdateInfo &, EntityComponentManager &_ecm)
 
       QMetaObject::invokeMethod(&this->dataPtr->treeModel, "AddEntity",
           Qt::QueuedConnection,
-          Q_ARG(unsigned int, _entity),
+          Q_ARG(Entity, _entity),
           Q_ARG(QString, QString::fromStdString(_name->Data())),
-          Q_ARG(unsigned int, parentEntity),
+          Q_ARG(Entity, parentEntity),
           Q_ARG(QString, entityType(_entity, _ecm)));
       return true;
     });
@@ -359,9 +377,9 @@ void EntityTree::Update(const UpdateInfo &, EntityComponentManager &_ecm)
 
       QMetaObject::invokeMethod(&this->dataPtr->treeModel, "AddEntity",
           Qt::QueuedConnection,
-          Q_ARG(unsigned int, _entity),
+          Q_ARG(Entity, _entity),
           Q_ARG(QString, QString::fromStdString(_name->Data())),
-          Q_ARG(unsigned int, parentEntity),
+          Q_ARG(Entity, parentEntity),
           Q_ARG(QString, entityType(_entity, _ecm)));
       return true;
     });
@@ -373,18 +391,67 @@ void EntityTree::Update(const UpdateInfo &, EntityComponentManager &_ecm)
   {
     QMetaObject::invokeMethod(&this->dataPtr->treeModel, "RemoveEntity",
         Qt::QueuedConnection,
-        Q_ARG(unsigned int, _entity));
+        Q_ARG(Entity, _entity));
     return true;
   });
+
+  {
+    // update the entity tree with new/removed entities from gui events
+    std::lock_guard<std::mutex> lock(this->dataPtr->newRemovedEntityMutex);
+
+    for (auto entity : this->dataPtr->newEntities)
+    {
+      // make sure the entity to be added has a name and parent
+      auto nameComp = _ecm.Component<components::Name>(entity);
+      if (!nameComp)
+      {
+        ignerr << "Could not add entity [" << entity << "] to the entity tree "
+               << "because it does not have a name component.\n";
+        continue;
+      }
+      auto parentComp = _ecm.Component<components::ParentEntity>(entity);
+      if (!parentComp)
+      {
+        ignerr << "Could not add entity [" << entity << "] to the entity tree "
+               << "because it does not have a parent entity component.\n";
+        continue;
+      }
+
+      // World children are top-level
+      auto parentEntity = parentComp->Data();
+      if (this->dataPtr->worldEntity != kNullEntity &&
+          parentEntity == this->dataPtr->worldEntity)
+      {
+        parentEntity = kNullEntity;
+      }
+
+      QMetaObject::invokeMethod(&this->dataPtr->treeModel, "AddEntity",
+          Qt::QueuedConnection,
+          Q_ARG(Entity, entity),
+          Q_ARG(QString, QString::fromStdString(nameComp->Data())),
+          Q_ARG(Entity, parentEntity),
+          Q_ARG(QString, entityType(entity, _ecm)));
+    }
+
+    for (auto entity : this->dataPtr->removedEntities)
+    {
+      QMetaObject::invokeMethod(&this->dataPtr->treeModel, "RemoveEntity",
+          Qt::QueuedConnection,
+          Q_ARG(Entity, entity));
+    }
+
+    this->dataPtr->newEntities.clear();
+    this->dataPtr->removedEntities.clear();
+  }
 }
 
 /////////////////////////////////////////////////
-void EntityTree::OnEntitySelectedFromQml(unsigned int _entity)
+void EntityTree::OnEntitySelectedFromQml(Entity _entity)
 {
   std::vector<Entity> entitySet {_entity};
   gui::events::EntitiesSelected event(entitySet, true);
-  ignition::gui::App()->sendEvent(
-      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
+  gz::gui::App()->sendEvent(
+      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
       &event);
 }
 
@@ -392,15 +459,74 @@ void EntityTree::OnEntitySelectedFromQml(unsigned int _entity)
 void EntityTree::DeselectAllEntities()
 {
   gui::events::DeselectAllEntities event(true);
-  ignition::gui::App()->sendEvent(
-      ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
+  gz::gui::App()->sendEvent(
+      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
       &event);
 }
 
+/////////////////////////////////////////////////
+void EntityTree::OnInsertEntity(const QString &_type)
+{
+  std::string modelSdfString = getPrimitive(_type.toStdString());
+  gz::gui::events::SpawnFromDescription event(modelSdfString);
+  gz::gui::App()->sendEvent(
+      gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+      &event);
+}
+
+/////////////////////////////////////////////////
+void EntityTree::OnLoadMesh(const QString &_mesh)
+{
+  std::string meshStr = _mesh.toStdString();
+  if (QUrl(_mesh).isLocalFile())
+  {
+    // mesh to sdf model
+    common::rtrim(meshStr);
+
+    if (!common::MeshManager::Instance()->IsValidFilename(meshStr))
+    {
+      QString errTxt = QString::fromStdString("Invalid URI: " + meshStr +
+        "\nOnly mesh file types DAE, OBJ, and STL are supported.");
+      return;
+    }
+
+    std::string filename = common::basename(meshStr);
+    std::vector<std::string> splitName = common::split(filename, ".");
+
+    std::string sdf = "<?xml version='1.0'?>"
+      "<sdf version='" + std::string(SDF_PROTOCOL_VERSION) + "'>"
+        "<model name='" + splitName[0] + "'>"
+          "<link name='link'>"
+            "<visual name='visual'>"
+              "<geometry>"
+                "<mesh>"
+                  "<uri>" + meshStr + "</uri>"
+                "</mesh>"
+              "</geometry>"
+            "</visual>"
+            "<collision name='collision'>"
+              "<geometry>"
+                "<mesh>"
+                  "<uri>" + meshStr + "</uri>"
+                "</mesh>"
+              "</geometry>"
+            "</collision>"
+          "</link>"
+        "</model>"
+      "</sdf>";
+
+    gz::gui::events::SpawnFromDescription event(sdf);
+    gz::gui::App()->sendEvent(
+        gz::gui::App()->findChild<gz::gui::MainWindow *>(),
+        &event);
+
+  }
+}
+
 /////////////////////////////////////////////////
 bool EntityTree::eventFilter(QObject *_obj, QEvent *_event)
 {
-  if (_event->type() == ignition::gazebo::gui::events::EntitiesSelected::kType)
+  if (_event->type() == gui::events::EntitiesSelected::kType)
   {
     auto selectedEvent =
         reinterpret_cast<gui::events::EntitiesSelected *>(_event);
@@ -413,12 +539,12 @@ bool EntityTree::eventFilter(QObject *_obj, QEvent *_event)
 
         QMetaObject::invokeMethod(this->PluginItem(), "onEntitySelectedFromCpp",
             Qt::QueuedConnection, Q_ARG(QVariant,
-            QVariant(static_cast<unsigned int>(entity))));
+            QVariant(static_cast<qulonglong>(entity))));
       }
     }
   }
   else if (_event->type() ==
-           ignition::gazebo::gui::events::DeselectAllEntities::kType)
+           gui::events::DeselectAllEntities::kType)
   {
     auto deselectAllEvent =
         reinterpret_cast<gui::events::DeselectAllEntities *>(_event);
@@ -428,11 +554,28 @@ bool EntityTree::eventFilter(QObject *_obj, QEvent *_event)
           Qt::QueuedConnection);
     }
   }
+  else if (_event->type() ==
+           ignition::gazebo::gui::events::GuiNewRemovedEntities::kType)
+  {
+    std::lock_guard<std::mutex> lock(this->dataPtr->newRemovedEntityMutex);
+    auto addedRemovedEvent =
+        reinterpret_cast<gui::events::GuiNewRemovedEntities *>(_event);
+    if (addedRemovedEvent)
+    {
+      // TODO(chapulina) Make these entities visually different from entities
+      // created from the server.
+      for (auto entity : addedRemovedEvent->NewEntities())
+        this->dataPtr->newEntities.insert(entity);
+
+      for (auto entity : addedRemovedEvent->RemovedEntities())
+        this->dataPtr->removedEntities.insert(entity);
+    }
+  }
 
   // Standard event processing
   return QObject::eventFilter(_obj, _event);
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(ignition::gazebo::EntityTree,
-                    ignition::gui::Plugin)
+IGNITION_ADD_PLUGIN(EntityTree,
+                    gz::gui::Plugin)
