@@ -17,24 +17,24 @@
 
 #include <algorithm>
 #include <iostream>
-#include <ignition/common/Console.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/gui/Application.hh>
-#include <ignition/gui/MainWindow.hh>
-#include <ignition/math/Helpers.hh>
-#include <ignition/plugin/Register.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/transport/TopicUtils.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/gui/Application.hh>
+#include <gz/gui/MainWindow.hh>
+#include <gz/math/Helpers.hh>
+#include <gz/plugin/Register.hh>
+#include <gz/transport/Node.hh>
+#include <gz/transport/TopicUtils.hh>
 
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/JointAxis.hh"
-#include "ignition/gazebo/components/JointPosition.hh"
-#include "ignition/gazebo/components/JointType.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/EntityComponentManager.hh"
-#include "ignition/gazebo/gui/GuiEvents.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/JointAxis.hh"
+#include "gz/sim/components/JointPosition.hh"
+#include "gz/sim/components/JointType.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/EntityComponentManager.hh"
+#include "gz/sim/gui/GuiEvents.hh"
 
 #include "JointPositionController.hh"
 
@@ -162,8 +162,8 @@ void JointPositionController::LoadConfig(
     }
   }
 
-  ignition::gui::App()->findChild<
-      ignition::gui::MainWindow *>()->installEventFilter(this);
+  gz::gui::App()->findChild<
+      gz::gui::MainWindow *>()->installEventFilter(this);
 
   // Connect model
   this->Context()->setContextProperty(
@@ -240,12 +240,7 @@ void JointPositionController::Update(const UpdateInfo &,
     // Add joint to list
     else
     {
-      // TODO(louise) Blocking here is not the best idea
-      QMetaObject::invokeMethod(&this->dataPtr->jointsModel,
-          "AddJoint",
-          Qt::BlockingQueuedConnection,
-          Q_RETURN_ARG(QStandardItem *, item),
-          Q_ARG(Entity, jointEntity));
+      item = this->dataPtr->jointsModel.AddJoint(jointEntity);
       newItem = true;
     }
 
@@ -296,7 +291,7 @@ void JointPositionController::Update(const UpdateInfo &,
       QMetaObject::invokeMethod(&this->dataPtr->jointsModel,
           "RemoveJoint",
           Qt::QueuedConnection,
-          Q_ARG(Entity, jointEntity));
+          Q_ARG(ignition::gazebo::Entity, jointEntity));
     }
   }
 }
@@ -306,7 +301,8 @@ bool JointPositionController::eventFilter(QObject *_obj, QEvent *_event)
 {
   if (!this->dataPtr->locked)
   {
-    if (_event->type() == gazebo::gui::events::EntitiesSelected::kType)
+    if (_event->type() ==
+        ignition::gazebo::gui::events::EntitiesSelected::kType)
     {
       auto event = reinterpret_cast<gui::events::EntitiesSelected *>(_event);
       if (event && !event->Data().empty())
@@ -315,7 +311,8 @@ bool JointPositionController::eventFilter(QObject *_obj, QEvent *_event)
       }
     }
 
-    if (_event->type() == gazebo::gui::events::DeselectAllEntities::kType)
+    if (_event->type() ==
+        ignition::gazebo::gui::events::DeselectAllEntities::kType)
     {
       auto event = reinterpret_cast<gui::events::DeselectAllEntities *>(
           _event);
@@ -379,7 +376,7 @@ void JointPositionController::OnCommand(const QString &_jointName, double _pos)
 {
   std::string jointName = _jointName.toStdString();
 
-  ignition::msgs::Double msg;
+  msgs::Double msg;
   msg.set_data(_pos);
   auto topic = transport::TopicUtils::AsValidTopic("/model/" +
       this->dataPtr->modelName.toStdString() + "/joint/" + jointName +
@@ -392,7 +389,7 @@ void JointPositionController::OnCommand(const QString &_jointName, double _pos)
     return;
   }
 
-  auto pub = this->dataPtr->node.Advertise<ignition::msgs::Double>(topic);
+  auto pub = this->dataPtr->node.Advertise<msgs::Double>(topic);
   pub.Publish(msg);
 }
 
@@ -409,7 +406,7 @@ void JointPositionController::OnReset()
       continue;
     }
 
-    ignition::msgs::Double msg;
+    msgs::Double msg;
     msg.set_data(0);
     auto topic = transport::TopicUtils::AsValidTopic("/model/" +
         this->dataPtr->modelName.toStdString() + "/joint/" + jointName +
@@ -422,11 +419,11 @@ void JointPositionController::OnReset()
       return;
     }
 
-    auto pub = this->dataPtr->node.Advertise<ignition::msgs::Double>(topic);
+    auto pub = this->dataPtr->node.Advertise<msgs::Double>(topic);
     pub.Publish(msg);
   }
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(ignition::gazebo::gui::JointPositionController,
-                    ignition::gui::Plugin)
+IGNITION_ADD_PLUGIN(JointPositionController,
+                    gz::gui::Plugin)
