@@ -19,30 +19,29 @@
 #ifdef _MSC_VER
 #pragma warning(push, 0)
 #endif
-#include <ignition/msgs/double.pb.h>
+#include <gz/msgs/double.pb.h>
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
-#include <ignition/common/Console.hh>
-#include <ignition/gui/Application.hh>
-#include <ignition/gui/MainWindow.hh>
-#include <ignition/gui/Plugin.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
-#include <ignition/utils/SuppressWarning.hh>
+#include <gz/common/Console.hh>
+#include <gz/gui/Application.hh>
+#include <gz/gui/MainWindow.hh>
+#include <gz/gui/Plugin.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/JointAxis.hh"
-#include "ignition/gazebo/components/JointPosition.hh"
-#include "ignition/gazebo/components/JointType.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/gui/GuiRunner.hh"
-#include "ignition/gazebo/EntityComponentManager.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/JointAxis.hh"
+#include "gz/sim/components/JointPosition.hh"
+#include "gz/sim/components/JointType.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/EntityComponentManager.hh"
+#include "gz/sim/test_config.hh"
 #include "../../../../test/helpers/EnvTestFixture.hh"
 
+#include "../../GuiRunner.hh"
 #include "JointPositionController.hh"
 
 int g_argc = 1;
@@ -63,11 +62,8 @@ TEST_F(JointPositionControllerGui, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Load))
   ASSERT_NE(nullptr, app);
   app->AddPluginPath(std::string(PROJECT_BINARY_PATH) + "/lib");
 
-  // Create GUI runner to handle gazebo::gui plugins
-  // TODO(anyone) Remove deprecation guard once GuiRunner becomes private
-  IGN_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-  auto runner = new gazebo::GuiRunner("test");
-  IGN_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
+  // Create GUI runner to handle ignition::gazebo::gui plugins
+  auto runner = new ignition::gazebo::GuiRunner("test");
   runner->setParent(gui::App());
 
   // Add plugin
@@ -79,7 +75,7 @@ TEST_F(JointPositionControllerGui, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Load))
 
   // Get plugin
   auto plugins = win->findChildren<
-      gazebo::gui::JointPositionController *>();
+      ignition::gazebo::gui::JointPositionController *>();
   EXPECT_EQ(plugins.size(), 1);
 
   auto plugin = plugins[0];
@@ -95,7 +91,7 @@ TEST_F(JointPositionControllerGui, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Load))
 
   EXPECT_LT(sleep, maxSleep);
   EXPECT_EQ(plugin->Title(), "Joint position controller");
-  EXPECT_EQ(plugin->ModelEntity(), gazebo::kNullEntity);
+  EXPECT_EQ(plugin->ModelEntity(), ignition::gazebo::kNullEntity);
   EXPECT_EQ(plugin->ModelName(), QString("No model selected"))
       << plugin->ModelName().toStdString();
   EXPECT_FALSE(plugin->Locked());
@@ -109,24 +105,28 @@ TEST_F(JointPositionControllerGui,
     IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(PublishCommand))
 {
   // Create a model with a joint
-  gazebo::EntityComponentManager ecm;
+  ignition::gazebo::EntityComponentManager ecm;
 
   auto modelEntity = ecm.CreateEntity();
-  ecm.CreateComponent(modelEntity, gazebo::components::Model());
-  ecm.CreateComponent(modelEntity, gazebo::components::Name("model_name"));
+  ecm.CreateComponent(modelEntity, ignition::gazebo::components::Model());
+  ecm.CreateComponent(modelEntity,
+      ignition::gazebo::components::Name("model_name"));
 
   auto jointEntity = ecm.CreateEntity();
-  ecm.CreateComponent(jointEntity, gazebo::components::Joint());
-  ecm.CreateComponent(jointEntity, gazebo::components::Name("joint_name"));
-  ecm.CreateComponent(jointEntity, gazebo::components::ParentEntity(
+  ecm.CreateComponent(jointEntity, ignition::gazebo::components::Joint());
+  ecm.CreateComponent(jointEntity,
+      ignition::gazebo::components::Name("joint_name"));
+  ecm.CreateComponent(jointEntity, ignition::gazebo::components::ParentEntity(
       modelEntity));
-  ecm.CreateComponent(jointEntity, gazebo::components::JointPosition({0.1}));
-  ecm.CreateComponent(jointEntity, gazebo::components::JointType(
+  ecm.CreateComponent(jointEntity,
+      ignition::gazebo::components::JointPosition({0.1}));
+  ecm.CreateComponent(jointEntity, ignition::gazebo::components::JointType(
       sdf::JointType::REVOLUTE));
   sdf::JointAxis jointAxis;
   jointAxis.SetLower(-1.0);
   jointAxis.SetUpper(1.0);
-  ecm.CreateComponent(jointEntity, gazebo::components::JointAxis(jointAxis));
+  ecm.CreateComponent(jointEntity,
+      ignition::gazebo::components::JointAxis(jointAxis));
 
   // Populate state message
   msgs::SerializedStepMap stepMsg;
@@ -150,11 +150,8 @@ TEST_F(JointPositionControllerGui,
   ASSERT_NE(nullptr, app);
   app->AddPluginPath(std::string(PROJECT_BINARY_PATH) + "/lib");
 
-  // Create GUI runner to handle gazebo::gui plugins
-  // TODO(anyone) Remove deprecation guard once GuiRunner becomes private
-  IGN_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-  auto runner = new gazebo::GuiRunner("test");
-  IGN_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
+  // Create GUI runner to handle ignition::gazebo::gui plugins
+  auto runner = new ignition::gazebo::GuiRunner("test");
   runner->setParent(gui::App());
 
   // Load plugin
@@ -179,7 +176,7 @@ TEST_F(JointPositionControllerGui,
 
   // Get plugin
   auto plugins = win->findChildren<
-      gazebo::gui::JointPositionController *>();
+      ignition::gazebo::gui::JointPositionController *>();
   EXPECT_EQ(plugins.size(), 1);
 
   auto plugin = plugins[0];
@@ -195,7 +192,7 @@ TEST_F(JointPositionControllerGui,
   }
   EXPECT_LT(sleep, maxSleep);
 
-  EXPECT_EQ(plugin->ModelEntity(), gazebo::kNullEntity);
+  EXPECT_EQ(plugin->ModelEntity(), ignition::gazebo::kNullEntity);
   EXPECT_EQ(plugin->ModelName(), QString("No model selected"))
       << plugin->ModelName().toStdString();
   EXPECT_FALSE(plugin->Locked());
