@@ -17,27 +17,27 @@
 
 #include "JointStatePublisher.hh"
 
-#include <ignition/msgs/model.pb.h>
+#include <gz/msgs/model.pb.h>
 
 #include <string>
 #include <vector>
 
-#include <ignition/plugin/Register.hh>
+#include <gz/plugin/Register.hh>
 
-#include "ignition/gazebo/components/ChildLinkName.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/Joint.hh"
-#include "ignition/gazebo/components/JointAxis.hh"
-#include "ignition/gazebo/components/JointForce.hh"
-#include "ignition/gazebo/components/JointPosition.hh"
-#include "ignition/gazebo/components/JointVelocity.hh"
-#include "ignition/gazebo/components/ParentEntity.hh"
-#include "ignition/gazebo/components/ParentLinkName.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/Util.hh"
+#include "gz/sim/components/ChildLinkName.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Joint.hh"
+#include "gz/sim/components/JointAxis.hh"
+#include "gz/sim/components/JointForce.hh"
+#include "gz/sim/components/JointPosition.hh"
+#include "gz/sim/components/JointVelocity.hh"
+#include "gz/sim/components/ParentEntity.hh"
+#include "gz/sim/components/ParentLinkName.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/Util.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace systems;
 
 //////////////////////////////////////////////////
@@ -69,7 +69,7 @@ void JointStatePublisher::Configure(
     while (elem)
     {
       std::string jointName = elem->Get<std::string>();
-      gazebo::Entity jointEntity = this->model.JointByName(_ecm, jointName);
+      Entity jointEntity = this->model.JointByName(_ecm, jointName);
       if (jointEntity != kNullEntity)
       {
         this->CreateComponents(_ecm, jointEntity);
@@ -105,7 +105,7 @@ void JointStatePublisher::Configure(
 
 //////////////////////////////////////////////////
 void JointStatePublisher::CreateComponents(EntityComponentManager &_ecm,
-    gazebo::Entity _joint)
+    Entity _joint)
 {
   if (this->joints.find(_joint) != this->joints.end())
   {
@@ -313,9 +313,13 @@ void JointStatePublisher::PostUpdate(const UpdateInfo &_info,
 }
 
 IGNITION_ADD_PLUGIN(JointStatePublisher,
-                    ignition::gazebo::System,
+                    System,
                     JointStatePublisher::ISystemConfigure,
                     JointStatePublisher::ISystemPostUpdate)
 
+IGNITION_ADD_PLUGIN_ALIAS(JointStatePublisher,
+    "gz::sim::systems::JointStatePublisher")
+
+// TODO(CH3): Deprecated, remove on version 8
 IGNITION_ADD_PLUGIN_ALIAS(JointStatePublisher,
     "ignition::gazebo::systems::JointStatePublisher")
