@@ -31,7 +31,7 @@
 #include <gz/sim/components/Pose.hh>
 #include <gz/sim/components/Sensor.hh>
 #include <gz/sim/components/World.hh>
-#include <ignition/msgs.hh>
+#include <gz/msgs.hh>
 #include <gz/transport.hh>
 #include <gz/plugin/Register.hh>
 #include <gz/sim/SdfEntityCreator.hh>
@@ -403,14 +403,21 @@ void LogicalAudioSensorPluginPrivate::CreateAudioSource(
     };
 
   // create services for this source
-  const auto full_name = scopedName(entity, _ecm);
-  if (!this->node.Advertise(full_name + "/play", playSrvCb))
+  const auto fullName = scopedName(entity, _ecm);
+  auto validName = transport::TopicUtils::AsValidTopic(fullName);
+  if (validName.empty())
+  {
+    ignerr << "Failed to create valid topics with entity scoped name ["
+           << fullName << "]" << std::endl;
+    return;
+  }
+  if (!this->node.Advertise(validName + "/play", playSrvCb))
   {
     ignerr << "Error advertising the play source service for source "
       << id << " in entity " << _parent << ". " << kSourceSkipMsg;
     return;
   }
-  if (!this->node.Advertise(full_name + "/stop", stopSrvCb))
+  if (!this->node.Advertise(validName + "/stop", stopSrvCb))
   {
     ignerr << "Error advertising the stop source service for source "
       << id << " in entity " << _parent << ". " << kSourceSkipMsg;
