@@ -6,6 +6,7 @@
  * Copyright 2015 Markus Achtelik, ASL, ETH Zurich, Switzerland
  * Copyright 2016 Geoffrey Hunter <gbmhunter@gmail.com>
  * Copyright (C) 2019 Open Source Robotics Foundation
+ * Copyright (C) 2022 Benjamin Perseghetti, Rudis Laboratories
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,7 +35,7 @@
 #include <gz/math/Helpers.hh>
 #include <gz/math/Pose3.hh>
 #include <gz/math/Vector3.hh>
-#include <ignition/msgs.hh>
+#include <gz/msgs.hh>
 
 #include <sdf/sdf.hh>
 
@@ -49,6 +50,7 @@
 #include "gz/sim/components/Wind.hh"
 #include "gz/sim/Link.hh"
 #include "gz/sim/Model.hh"
+#include "gz/sim/Util.hh"
 
 // from rotors_gazebo_plugins/include/rotors_gazebo_plugins/common.h
 /// \brief    This class can be used to apply a first order filter on a signal.
@@ -250,7 +252,8 @@ void MulticopterMotorModel::Configure(const Entity &_entity,
   }
   else
   {
-    ignerr << "Please specify a robotNamespace.\n";
+    ignwarn << "No robotNamespace set using entity name.\n";
+    this->dataPtr->robotNamespace = this->dataPtr->model.Name(_ecm);
   }
 
   // Get params from SDF
@@ -357,8 +360,18 @@ void MulticopterMotorModel::Configure(const Entity &_entity,
           this->dataPtr->refMotorInput);
 
   // Subscribe to actuator command messages
-  std::string topic{this->dataPtr->robotNamespace + "/"
-                  + this->dataPtr->commandSubTopic};
+  std::string topic = transport::TopicUtils::AsValidTopic(
+      this->dataPtr->robotNamespace + "/" + this->dataPtr->commandSubTopic);
+  if (topic.empty())
+  {
+    ignerr << "Failed to create topic for [" << this->dataPtr->robotNamespace
+           << "]" << std::endl;
+    return;
+  }
+  else
+  {
+    igndbg << "Listening to topic: " << topic << std::endl;
+  }
   this->dataPtr->node.Subscribe(topic,
       &MulticopterMotorModelPrivate::OnActuatorMsg, this->dataPtr.get());
 }
