@@ -16,30 +16,31 @@
  */
 
 #include <algorithm>
+#include <atomic>
 #include <optional>
 #include <string>
 #include <vector>
 
-#include <ignition/common/Profiler.hh>
-#include <ignition/plugin/Register.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/common/Time.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/plugin/Register.hh>
+#include <gz/transport/Node.hh>
+#include <gz/common/Time.hh>
 
 #include <sdf/Element.hh>
 
-#include "ignition/gazebo/components/ContactSensor.hh"
-#include "ignition/gazebo/components/ContactSensorData.hh"
-#include "ignition/gazebo/components/Collision.hh"
-#include "ignition/gazebo/components/DepthCamera.hh"
-#include "ignition/gazebo/components/Link.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/Sensor.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/components/Geometry.hh"
+#include "gz/sim/components/ContactSensor.hh"
+#include "gz/sim/components/ContactSensorData.hh"
+#include "gz/sim/components/Collision.hh"
+#include "gz/sim/components/DepthCamera.hh"
+#include "gz/sim/components/Link.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Sensor.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/components/Geometry.hh"
 #include "sdf/Box.hh"
 
-#include "ignition/gazebo/Model.hh"
-#include "ignition/gazebo/Util.hh"
+#include "gz/sim/Model.hh"
+#include "gz/sim/Util.hh"
 
 #include "OpticalTactilePlugin.hh"
 
@@ -55,8 +56,8 @@ class ignition::gazebo::systems::OpticalTactilePluginPrivate
   public: void Load(const EntityComponentManager &_ecm);
 
   /// \brief Actual function that enables the plugin.
-  /// \param[in] _value True to enable plugin.
-  public: void Enable(const bool _value);
+  /// \param[in] _req Whether to enable the plugin or disable it.
+  public: void Enable(const ignition::msgs::Boolean &_req);
 
   /// \brief Callback for the depth camera
   /// \param[in] _msg Message from the subscribed topic
@@ -98,6 +99,9 @@ class ignition::gazebo::systems::OpticalTactilePluginPrivate
   /// \brief Whether to visualize the normal forces.
   public: bool visualizeForces{false};
 
+  /// \brief Whether to visualize the contacts.
+  public: bool visualizeContacts{false};
+
   /// \brief Model interface.
   public: Model model{kNullEntity};
 
@@ -112,7 +116,7 @@ class ignition::gazebo::systems::OpticalTactilePluginPrivate
   public: ignition::gazebo::Entity objectCollisionEntity;
 
   /// \brief Whether the plugin is enabled.
-  public: bool enabled{true};
+  public: std::atomic<bool> enabled{true};
 
   /// \brief Initialization flag.
   public: bool initialized{false};
@@ -150,7 +154,7 @@ class ignition::gazebo::systems::OpticalTactilePluginPrivate
   public: bool visualizeSensor{false};
 
   /// \brief Size of the contact sensor
-  public: ignition::math::Vector3d sensorSize;
+  public: ignition::math::Vector3d sensorSize{0.005, 0.02, 0.02};
 
   /// \brief Extended sensing distance. The sensor will output data coming from
   /// its volume plus this distance.
@@ -164,6 +168,12 @@ class ignition::gazebo::systems::OpticalTactilePluginPrivate
 
   /// \brief Flag for allowing the plugin to output error/warning only once
   public: bool initErrorPrinted{false};
+
+  /// \brief Normal forces publisher
+  public: ignition::transport::Node::Publisher normalForcesPub;
+
+  /// \brief Namespace for transport topics
+  public: std::string ns{"optical_tactile_sensor"};
 };
 
 //////////////////////////////////////////////////
@@ -228,6 +238,16 @@ void OpticalTactilePlugin::Configure(const Entity &_entity,
     this->dataPtr->visualizeForces = _sdf->Get<bool>("visualize_forces");
   }
 
+  if (!_sdf->HasElement("visualize_contacts"))
+  {
+    igndbg << "Missing parameter <visualize_contacts>, "
+      << "setting to " << this->dataPtr->visualizeContacts << std::endl;
+  }
+  else
+  {
+    this->dataPtr->visualizeContacts = _sdf->Get<bool>("visualize_contacts");
+  }
+
   if (!_sdf->HasElement("extended_sensing"))
   {
     igndbg << "Missing parameter <extended_sensing>, "
@@ -273,6 +293,73 @@ void OpticalTactilePlugin::Configure(const Entity &_entity,
       this->dataPtr->forceLength = _sdf->Get<double>("force_length");
     }
   }
+
+  if (!_sdf->HasElement("namespace"))
+  {
+    igndbg << "Missing parameter <namespace>, "
+      << "setting to " << this->dataPtr->ns << std::endl;
+  }
+  else
+  {
+    this->dataPtr->ns = _sdf->Get<std::string>("namespace");
+  }
+
+  // Get the size of the sensor from the SDF
+  // If there's no <collision> specified inside <link>, a default one
+  // is set
+  if (_sdf->GetParent() != nullptr)
+  {
+    if (_sdf->GetParent()->GetElement("link") != nullptr)
+    {
+      if (_sdf->GetParent()->GetElement("link")->GetElement("collision")
+          != nullptr)
+      {
+        if (_sdf->GetParent()->GetElement("link")->GetElement("collision")->
+            GetElement("geometry") != nullptr)
+        {
+          if (_sdf->GetParent()->GetElement("link")->GetElement("collision")->
+              GetElement("geometry")->GetElement("box") != nullptr)
+          {
+            this->dataPtr->sensorSize =
+              _sdf->GetParent()->GetElement("link")->GetElement("collision")->
+              GetElement("geometry")->GetElement("box")->
+              Get<ignition::math::Vector3d>("size");
+            igndbg << "Setting sensor size to box collision size: ["
+                   << this->dataPtr->sensorSize << "]" << std::endl;
+          }
+        }
+      }
+    }
+  }
+
+  // Advertise topic for normal forces
+  std::string normalForcesTopic = "/" + this->dataPtr->ns + "/normal_forces";
+  this->dataPtr->normalForcesPub =
+    this->dataPtr->node.Advertise<ignition::msgs::Image>(normalForcesTopic);
+  if (!this->dataPtr->normalForcesPub)
+  {
+    ignerr << "Error advertising topic [" << normalForcesTopic << "]"
+      << std::endl;
+  }
+  else
+  {
+    ignmsg << "Topic publishing normal forces [" << normalForcesTopic << "]"
+           << std::endl;
+  }
+
+  // Advertise enabling service
+  std::string enableService = "/" + this->dataPtr->ns + "/enable";
+  if (!this->dataPtr->node.Advertise(enableService,
+      &OpticalTactilePluginPrivate::Enable, this->dataPtr.get()))
+  {
+    ignerr << "Error advertising service [" << enableService << "]"
+      << std::endl;
+  }
+  else
+  {
+    ignmsg << "Service to enable tactile sensor [" << enableService << "]"
+           << std::endl;
+  }
 }
 
 //////////////////////////////////////////////////
@@ -282,7 +369,7 @@ void OpticalTactilePlugin::PreUpdate(const UpdateInfo &_info,
   IGN_PROFILE("OpticalTactilePlugin::PreUpdate");
 
   // Nothing left to do if paused
-  if (_info.paused)
+  if (_info.paused || !this->dataPtr->enabled)
     return;
 
   if (!this->dataPtr->initialized)
@@ -327,15 +414,26 @@ void OpticalTactilePlugin::PreUpdate(const UpdateInfo &_info,
 //////////////////////////////////////////////////
 void OpticalTactilePlugin::PostUpdate(
   const ignition::gazebo::UpdateInfo &_info,
-  const ignition::gazebo::EntityComponentManager &/*_ecm*/)
+  const ignition::gazebo::EntityComponentManager &_ecm)
 {
   IGN_PROFILE("OpticalTactilePlugin::PostUpdate");
 
   // Nothing left to do if paused or failed to initialize.
-  if (_info.paused || !this->dataPtr->initialized)
+  if (_info.paused || !this->dataPtr->initialized || !this->dataPtr->enabled)
     return;
 
   // TODO(anyone) Get ContactSensor data and merge it with DepthCamera data
+  if (this->dataPtr->visualizeContacts)
+  {
+    auto *contacts =
+      _ecm.Component<components::ContactSensorData>(
+        this->dataPtr->sensorCollisionEntity);
+
+    if (nullptr != contacts)
+    {
+      this->dataPtr->visualizePtr->RequestContactsMarkerMsg(contacts);
+    }
+  }
 
   // Process camera message if it's new
   {
@@ -517,16 +615,26 @@ void OpticalTactilePluginPrivate::Load(const EntityComponentManager &_ecm)
       this->sensorSize,
       this->forceLength,
       this->cameraUpdateRate,
-      this->depthCameraOffset,
-      this->visualizationResolution);
+      this->depthCameraOffset);
 
   this->initialized = true;
 }
 
 //////////////////////////////////////////////////
-void OpticalTactilePluginPrivate::Enable(const bool /*_value*/)
+void OpticalTactilePluginPrivate::Enable(const ignition::msgs::Boolean &_req)
 {
-  // todo(mcres) Implement method
+  if (_req.data() != this->enabled)
+  {
+    ignmsg << "Enabling optical tactile sensor with namespace [" << this->ns
+           << "]: " << _req.data() << std::endl;
+  }
+
+  this->enabled = _req.data();
+
+  if (!_req.data())
+  {
+    this->visualizePtr->RemoveNormalForcesAndContactsMarkers();
+  }
 }
 
 //////////////////////////////////////////////////
@@ -535,7 +643,7 @@ void OpticalTactilePluginPrivate::DepthCameraCallback(
 {
   // This check avoids running the callback at t=0 and getting
   // unexpected markers in the scene
-  if (!this->initialized)
+  if (!this->initialized || !this->enabled)
     return;
 
   // Check whether DepthCamera returns FLOAT32 data
@@ -652,6 +760,16 @@ void OpticalTactilePluginPrivate::ComputeNormalForces(
   // Declare variables for storing the XYZ points
   ignition::math::Vector3f p1, p2, p3, p4, markerPosition;
 
+  // Message for publishing normal forces
+  ignition::msgs::Image normalsMsg;
+  normalsMsg.set_width(_msg.width());
+  normalsMsg.set_height(_msg.height());
+  normalsMsg.set_step(3 * sizeof(float) * _msg.width());
+  normalsMsg.set_pixel_format_type(ignition::msgs::PixelFormatType::R_FLOAT32);
+
+  std::vector<float> normalForcesBuffer(3 * _msg.width() * _msg.height());
+  uint32_t bufferIndex;
+
   // Marker messages representing the normal forces
   ignition::msgs::Marker positionMarkerMsg;
   ignition::msgs::Marker forceMarkerMsg;
@@ -682,8 +800,15 @@ void OpticalTactilePluginPrivate::ComputeNormalForces(
       // https://github.com/ignitionrobotics/ign-math/issues/144
       ignition::math::Vector3f normalForce = direction.Normalized();
 
-      // todo(mcres) Normal forces are computed even if visualization
-      // is turned off. These forces should be published in the future.
+      // Add force to buffer
+      // Forces buffer is composed of XYZ coordinates, while _msg buffer is
+      // made up of XYZRGB values
+
+      bufferIndex = j * (_msg.width() * 3) + i * 3;
+      normalForcesBuffer[bufferIndex] = normalForce.X();
+      normalForcesBuffer[bufferIndex+1] = normalForce.Y();
+      normalForcesBuffer[bufferIndex+2] = normalForce.Z();
+
       if (!_visualizeForces)
         continue;
 
@@ -694,6 +819,14 @@ void OpticalTactilePluginPrivate::ComputeNormalForces(
     }
   }
 
+  std::string *dataStr = normalsMsg.mutable_data();
+  dataStr->resize(sizeof(float) * normalForcesBuffer.size());
+  memcpy(&((*dataStr)[0]), normalForcesBuffer.data(), dataStr->size());
+
+  // Publish message
+
+  this->normalForcesPub.Publish(normalsMsg);
+
   if (_visualizeForces)
   {
     this->visualizePtr->RequestNormalForcesMarkerMsgs(positionMarkerMsg,
