@@ -16,27 +16,30 @@
  */
 #include <memory>
 #include <mutex>
+#include <limits>
 #include <string>
 
-#include <ignition/msgs/double.pb.h>
+#include <gz/msgs/double.pb.h>
 
-#include <ignition/math/Helpers.hh>
+#include <gz/math/Helpers.hh>
 
-#include <ignition/plugin/Register.hh>
+#include <gz/plugin/Register.hh>
 
-#include <ignition/transport/Node.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/gazebo/components/AngularVelocity.hh"
-#include "ignition/gazebo/components/BatterySoC.hh"
-#include "ignition/gazebo/components/ChildLinkName.hh"
-#include "ignition/gazebo/components/JointAxis.hh"
-#include "ignition/gazebo/components/JointVelocityCmd.hh"
-#include "ignition/gazebo/components/LinearVelocity.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/components/World.hh"
-#include "ignition/gazebo/Link.hh"
-#include "ignition/gazebo/Model.hh"
-#include "ignition/gazebo/Util.hh"
+#include "gz/sim/components/AngularVelocity.hh"
+#include "gz/sim/components/BatterySoC.hh"
+#include "gz/sim/components/BatteryPowerLoad.hh"
+#include "gz/sim/components/ChildLinkName.hh"
+#include "gz/sim/components/JointAxis.hh"
+#include "gz/sim/components/JointVelocityCmd.hh"
+#include "gz/sim/components/LinearVelocity.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/components/World.hh"
+#include "gz/sim/Link.hh"
+#include "gz/sim/Model.hh"
+#include "gz/sim/Util.hh"
 
 #include "Thruster.hh"
 
@@ -64,6 +67,9 @@ class ignition::gazebo::systems::ThrusterPrivateData
   /// \brief The link entity which will spin
   public: ignition::gazebo::Entity linkEntity;
 
+  /// \brief Battery consumer entity
+  public: Entity consumerEntity;
+
   /// \brief Axis along which the propeller spins. Expressed in the joint
   /// frame. Addume this doesn't change during simulation.
   public: ignition::math::Vector3d jointAxis;
@@ -98,18 +104,48 @@ class ignition::gazebo::systems::ThrusterPrivateData
   /// thrust
   public: double thrustCoefficient = 1;
 
+  /// \brief True if the thrust coefficient was set by configuration.
+  public: bool thrustCoefficientSet = false;
+
+  /// \brief Relative speed reduction between the water at the propeller vs
+  /// behind the vessel.
+  public: double wakeFraction = 0.2;
+
+  /// \brief Constant given by the open water propeller diagram. Used in the
+  /// calculation of the thrust coefficient.
+  public: double alpha1 = 1;
+
+  /// \brief Constant given by the open water propeller diagram. Used in the
+  /// calculation of the thrust coefficient.
+  public: double alpha2 = 0;
+
   /// \brief Density of fluid in kgm^-3, default: 1000kgm^-3
   public: double fluidDensity = 1000;
 
   /// \brief Diameter of propeller in m, default: 0.02
   public: double propellerDiameter = 0.02;
 
+  /// \brief Linear velocity of the vehicle.
+  public: double linearVelocity = 0.0;
+
   /// \brief Topic name used to control thrust.
   public: std::string topic = "";
 
+  /// \brief Battery entity used by the thruster to consume power.
+  public: std::string batteryName = "";
+
+  /// \brief Battery power load of the thruster.
+  public: double powerLoad = 0.0;
+
+  /// \brief Has the battery consumption being initialized.
+  public: bool batteryInitialized = false;
+
   /// \brief Callback for handling thrust update
   public: void OnCmdThrust(const msgs::Double &_msg);
 
+  /// \brief Recalculates and updates the thrust coefficient.
+  public: void UpdateThrustCoefficient();
+
   /// \brief Function which computes angular velocity from thrust
   /// \param[in] _thrust Thrust in N
   /// \return Angular velocity in rad/s
@@ -160,6 +196,7 @@ void Thruster::Configure(
   if (_sdf->HasElement("thrust_coefficient"))
   {
     this->dataPtr->thrustCoefficient = _sdf->Get<double>("thrust_coefficient");
+    this->dataPtr->thrustCoefficientSet = true;
   }
 
   // Get propeller diameter
@@ -174,6 +211,40 @@ void Thruster::Configure(
     this->dataPtr->fluidDensity = _sdf->Get<double>("fluid_density");
   }
 
+  // Get wake fraction number, default 0.2 otherwise
+  if (_sdf->HasElement("wake_fraction"))
+  {
+    this->dataPtr->wakeFraction = _sdf->Get<double>("wake_fraction");
+  }
+
+  // Get alpha_1, default to 1 othwewise
+  if (_sdf->HasElement("alpha_1"))
+  {
+    this->dataPtr->alpha1 = _sdf->Get<double>("alpha_1");
+    if (this->dataPtr->thrustCoefficientSet)
+    {
+      ignwarn << " The [alpha_2] value will be ignored as a "
+              << "[thrust_coefficient] was also defined through the SDF file."
+              << " If you want the system to use the alpha values to calculate"
+              << " and update the thrust coefficient please remove the "
+              << "[thrust_coefficient] value from the SDF file." << std::endl;
+    }
+  }
+
+  // Get alpha_2, default to 1 othwewise
+  if (_sdf->HasElement("alpha_2"))
+  {
+    this->dataPtr->alpha2 = _sdf->Get<double>("alpha_2");
+    if (this->dataPtr->thrustCoefficientSet)
+    {
+      ignwarn << " The [alpha_2] value will be ignored as a "
+              << "[thrust_coefficient] was also defined through the SDF file."
+              << " If you want the system to use the alpha values to calculate"
+              << " and update the thrust coefficient please remove the "
+              << "[thrust_coefficient] value from the SDF file." << std::endl;
+    }
+  }
+
   // Get a custom topic.
   if (_sdf->HasElement("topic"))
   {
@@ -235,6 +306,8 @@ void Thruster::Configure(
   enableComponent<components::AngularVelocity>(_ecm, this->dataPtr->linkEntity);
   enableComponent<components::WorldAngularVelocity>(_ecm,
       this->dataPtr->linkEntity);
+  enableComponent<ignition::gazebo::components::WorldLinearVelocity>(_ecm,
+      this->dataPtr->linkEntity);
 
   double minThrustCmd = this->dataPtr->cmdMin;
   double maxThrustCmd = this->dataPtr->cmdMax;
@@ -304,6 +377,22 @@ void Thruster::Configure(
   {
     igndbg << "Using velocity control for propeller joint." << std::endl;
   }
+
+  // Get power load and battery name info
+  if (_sdf->HasElement("power_load"))
+  {
+    if (!_sdf->HasElement("battery_name"))
+    {
+      ignerr << "Specified a <power_load> but missing <battery_name>."
+          "Specify a battery name so the power load can be assigned to it."
+          << std::endl;
+    }
+    else
+    {
+      this->dataPtr->powerLoad = _sdf->Get<double>("power_load");
+      this->dataPtr->batteryName = _sdf->Get<std::string>("battery_name");
+    }
+  }
 }
 
 /////////////////////////////////////////////////
@@ -321,6 +410,14 @@ void ThrusterPrivateData::OnCmdThrust(const msgs::Double &_msg)
 /////////////////////////////////////////////////
 double ThrusterPrivateData::ThrustToAngularVec(double _thrust)
 {
+  // Only update if the thrust coefficient was not set by configuration
+  // and angular velocity is not zero. Some velocity is needed to calculate
+  // the thrust coefficient otherwise it will never start moving.
+  if (!this->thrustCoefficientSet &&
+      std::abs(this->propellerAngVel) > std::numeric_limits<double>::epsilon())
+  {
+    this->UpdateThrustCoefficient();
+  }
   // Thrust is proportional to the Rotation Rate squared
   // See Thor I Fossen's  "Guidance and Control of ocean vehicles" p. 246
   auto propAngularVelocity = sqrt(abs(
@@ -333,6 +430,14 @@ double ThrusterPrivateData::ThrustToAngularVec(double _thrust)
   return propAngularVelocity;
 }
 
+/////////////////////////////////////////////////
+void ThrusterPrivateData::UpdateThrustCoefficient()
+{
+  this->thrustCoefficient = this->alpha1 + this->alpha2 *
+      (((1 - this->wakeFraction) * this->linearVelocity)
+      / (this->propellerAngVel * this->propellerDiameter));
+}
+
 /////////////////////////////////////////////////
 bool ThrusterPrivateData::HasSufficientBattery(
   const EntityComponentManager &_ecm) const
@@ -368,6 +473,52 @@ void Thruster::PreUpdate(
     return;
   }
 
+  // Intit battery consumption if it was set
+  if (!this->dataPtr->batteryName.empty() &&
+      !this->dataPtr->batteryInitialized)
+  {
+    this->dataPtr->batteryInitialized = true;
+
+    // Check that a battery exists with the specified name
+    Entity batteryEntity;
+    int numBatteriesWithName = 0;
+    _ecm.Each<components::BatterySoC, components::Name>(
+      [&](const Entity &_entity,
+        const components::BatterySoC */*_BatterySoC*/,
+        const components::Name *_name)->bool
+      {
+        if (this->dataPtr->batteryName == _name->Data())
+        {
+          ++numBatteriesWithName;
+          batteryEntity = _entity;
+        }
+        return true;
+      });
+    if (numBatteriesWithName == 0)
+    {
+      ignerr << "Can't assign battery consumption to battery: ["
+             << this->dataPtr->batteryName << "]. No batteries"
+             "were found with the given name." << std::endl;
+      return;
+    }
+    if (numBatteriesWithName > 1)
+    {
+      ignerr << "More than one battery found with name: ["
+             << this->dataPtr->batteryName << "]. Please make"
+             "sure battery names are unique within the system."
+             << std::endl;
+      return;
+    }
+
+    // Create the battery consumer entity and its component
+    this->dataPtr->consumerEntity = _ecm.CreateEntity();
+    components::BatteryPowerLoadInfo batteryPowerLoadInfo{
+        batteryEntity, this->dataPtr->powerLoad};
+    _ecm.CreateComponent(this->dataPtr->consumerEntity,
+        components::BatteryPowerLoad(batteryPowerLoadInfo));
+    _ecm.SetParentEntity(this->dataPtr->consumerEntity, batteryEntity);
+  }
+
   ignition::gazebo::Link link(this->dataPtr->linkEntity);
 
   auto pose = worldPose(this->dataPtr->linkEntity, _ecm);
@@ -384,6 +535,8 @@ void Thruster::PreUpdate(
   {
     std::lock_guard<std::mutex> lock(this->dataPtr->mtx);
     desiredThrust = this->dataPtr->thrust;
+    this->dataPtr->propellerAngVel =
+        this->dataPtr->ThrustToAngularVec(this->dataPtr->thrust);
     desiredPropellerAngVel = this->dataPtr->propellerAngVel;
   }
 
@@ -422,6 +575,11 @@ void Thruster::PreUpdate(
     _ecm,
     unitVector * desiredThrust,
     unitVector * torque);
+
+  // Update the LinearVelocity of the vehicle
+  this->dataPtr->linearVelocity =
+      _ecm.Component<ignition::gazebo::components::WorldLinearVelocity>(
+      this->dataPtr->linkEntity)->Data().Length();
 }
 
 /////////////////////////////////////////////////
