@@ -17,8 +17,8 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/msgs/empty.pb.h>
-#include <ignition/msgs/twist.pb.h>
+#include <gz/msgs/empty.pb.h>
+#include <gz/msgs/twist.pb.h>
 
 #include <optional>
 #include <regex>
@@ -26,24 +26,25 @@
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/Entity.hh"
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/Entity.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/test_config.hh"
 
 #include "helpers/Relay.hh"
 #include "helpers/UniqueTestDirectoryEnv.hh"
 #include "helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 class BreadcrumbsTest : public InternalFixture<::testing::Test>
 {
@@ -75,7 +76,8 @@ void remainingCb(const msgs::Int32 &_msg)
 
 /////////////////////////////////////////////////
 // This test checks the .../deploy/remaining topic
-TEST_F(BreadcrumbsTest, Remaining)
+// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Remaining))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -133,7 +135,7 @@ TEST_F(BreadcrumbsTest, Remaining)
 
 /////////////////////////////////////////////////
 // The test checks breadcrumbs are deployed at the correct pose
-TEST_F(BreadcrumbsTest, DeployAtOffset)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(DeployAtOffset))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -145,8 +147,8 @@ TEST_F(BreadcrumbsTest, DeployAtOffset)
       node.Advertise<msgs::Empty>("/model/vehicle_blue/breadcrumbs/B1/deploy");
 
   std::size_t iterTestStart = 1000;
-  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
-                             const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
+                             const EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // After 1000 iterations, stop the vehicle, spawn a breadcrumb
@@ -198,7 +200,7 @@ TEST_F(BreadcrumbsTest, DeployAtOffset)
 
 /////////////////////////////////////////////////
 // The test checks max deployments
-TEST_F(BreadcrumbsTest, MaxDeployments)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(MaxDeployments))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -210,8 +212,8 @@ TEST_F(BreadcrumbsTest, MaxDeployments)
       node.Advertise<msgs::Empty>("/model/vehicle_blue/breadcrumbs/B1/deploy");
 
   std::size_t iterTestStart = 1000;
-  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
-                             const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
+                             const EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // Every 1000 iterations, deploy
@@ -254,7 +256,7 @@ TEST_F(BreadcrumbsTest, MaxDeployments)
 /////////////////////////////////////////////////
 // The test checks that including models from fuel works. Also checks custom
 // topic
-TEST_F(BreadcrumbsTest, FuelDeploy)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(FuelDeploy))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -268,8 +270,8 @@ TEST_F(BreadcrumbsTest, FuelDeploy)
   const std::size_t nIters = iterTestStart + 2500;
   const std::size_t maxDeployments = 5;
   std::size_t deployCount = 0;
-  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
-                             const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
+                             const EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // Every 500 iterations, deploy
@@ -307,7 +309,7 @@ TEST_F(BreadcrumbsTest, FuelDeploy)
 
 /////////////////////////////////////////////////
 // The test checks that breadcrumbs can be performers
-TEST_F(BreadcrumbsTest, Performer)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(Performer))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -322,8 +324,8 @@ TEST_F(BreadcrumbsTest, Performer)
   const std::size_t nIters = iterTestStart + 10000;
 
   std::optional<math::Pose3d> initialPose;
-  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
-                             const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
+                             const EntityComponentManager &_ecm)
   {
     // Deploy a performer breadcrumb on a tile that's on a level, and ensure
     // that it keeps the tile from being unloaded.
@@ -381,7 +383,7 @@ TEST_F(BreadcrumbsTest, Performer)
 /////////////////////////////////////////////////
 // Test that the volume of the performer is set when deploying a performer
 // breadcrumb
-TEST_F(BreadcrumbsTest, PerformerSetVolume)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(PerformerSetVolume))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf", true);
@@ -395,8 +397,8 @@ TEST_F(BreadcrumbsTest, PerformerSetVolume)
   const std::size_t nIters = iterTestStart + 2000;
 
   std::optional<math::Pose3d> initialPose;
-  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
-                             const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
+                             const EntityComponentManager &_ecm)
   {
     // Deploy a performer breadcrumb on a tile that's on the default a level,
     // and check that it causes tile_1 to be loaded since the performer's volume
@@ -436,7 +438,7 @@ TEST_F(BreadcrumbsTest, PerformerSetVolume)
 
 /////////////////////////////////////////////////
 // The test verifies breadcrumbs physics is disabled using disable_physics_time
-TEST_F(BreadcrumbsTest, DeployDisablePhysics)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(DeployDisablePhysics))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -448,8 +450,8 @@ TEST_F(BreadcrumbsTest, DeployDisablePhysics)
       node.Advertise<msgs::Empty>("/model/vehicle_blue/breadcrumbs/B2/deploy");
 
   std::size_t iterTestStart = 1000;
-  testSystem.OnPostUpdate([&](const gazebo::UpdateInfo &_info,
-                              const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&](const UpdateInfo &_info,
+                              const EntityComponentManager &_ecm)
   {
     // Start moving the vehicle
     // After 1000 iterations, stop the vehicle, spawn a breadcrumb
@@ -514,7 +516,7 @@ TEST_F(BreadcrumbsTest, DeployDisablePhysics)
 /////////////////////////////////////////////////
 // The test verifies that if allow_renaming is true, the Breadcrumb system
 // renames spawned models if a model with the same name exists.
-TEST_F(BreadcrumbsTest, AllowRenaming)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(AllowRenaming))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs.sdf");
@@ -549,7 +551,7 @@ TEST_F(BreadcrumbsTest, AllowRenaming)
 /////////////////////////////////////////////////
 /// Return a list of model entities whose names match the given regex
 std::vector<Entity> ModelsByNameRegex(
-    const gazebo::EntityComponentManager &_ecm, const std::regex &_re)
+    const EntityComponentManager &_ecm, const std::regex &_re)
 {
   std::vector<Entity> entities;
   _ecm.Each<components::Model, components::Name>(
@@ -568,7 +570,7 @@ std::vector<Entity> ModelsByNameRegex(
 
 // The test checks that models containing Breadcrumbs can be unloaded and loaded
 // safely
-TEST_F(BreadcrumbsTest, LevelLoadUnload)
+TEST_F(BreadcrumbsTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(LevelLoadUnload))
 {
   // Start server
   this->LoadWorld("test/worlds/breadcrumbs_levels.sdf", true);
@@ -584,8 +586,8 @@ TEST_F(BreadcrumbsTest, LevelLoadUnload)
   std::regex reTile1{"tile_1"};
   std::regex reBreadcrumb{"B1_.*"};
   testSystem.OnPostUpdate(
-      [&](const gazebo::UpdateInfo &_info,
-          const gazebo::EntityComponentManager &_ecm)
+      [&](const UpdateInfo &_info,
+          const EntityComponentManager &_ecm)
       {
         // Ensure that tile_1 is loaded at the start, deploy a breadcrumb
         if (_info.iterations == iterTestStart)
