@@ -16,26 +16,26 @@
 */
 
 #include <gtest/gtest.h>
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/test_config.hh"
 
 #include "../helpers/Relay.hh"
 #include "../helpers/EnvTestFixture.hh"
 
 #define tol 10e-4
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace std::chrono_literals;
 
 /// \brief Test DiffDrive system
@@ -65,8 +65,8 @@ class DiffDriveTest : public InternalFixture<::testing::TestWithParam<int>>
       test::Relay testSystem;
 
       std::vector<math::Pose3d> poses;
-      testSystem.OnPostUpdate([&poses](const gazebo::UpdateInfo &,
-        const gazebo::EntityComponentManager &_ecm)
+      testSystem.OnPostUpdate([&poses](const UpdateInfo &,
+        const EntityComponentManager &_ecm)
         {
           auto id = _ecm.EntityByComponents(
             components::Model(),
@@ -128,8 +128,8 @@ class DiffDriveTest : public InternalFixture<::testing::TestWithParam<int>>
       double desiredLinVel = movementDirection * 10.5;
       double desiredAngVel = 0.2;
       velocityRamp.OnPreUpdate(
-          [&](const gazebo::UpdateInfo &/*_info*/,
-              const gazebo::EntityComponentManager &)
+          [&](const UpdateInfo &/*_info*/,
+              const EntityComponentManager &)
           {
             msgs::Set(msg.mutable_linear(),
                       math::Vector3d(desiredLinVel, 0, 0));
@@ -249,8 +249,8 @@ TEST_P(DiffDriveTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(SkidPublishCmd))
   test::Relay testSystem;
 
   std::vector<math::Pose3d> poses;
-  testSystem.OnPostUpdate([&poses](const gazebo::UpdateInfo &,
-    const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&poses](const UpdateInfo &,
+    const EntityComponentManager &_ecm)
     {
       auto id = _ecm.EntityByComponents(
         components::Model(),
@@ -351,8 +351,8 @@ TEST_P(DiffDriveTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(EnableDisableCmd))
   test::Relay testSystem;
 
   std::vector<math::Pose3d> poses;
-  testSystem.OnPostUpdate([&poses](const gazebo::UpdateInfo &,
-    const gazebo::EntityComponentManager &_ecm)
+  testSystem.OnPostUpdate([&poses](const UpdateInfo &,
+    const EntityComponentManager &_ecm)
     {
       auto id = _ecm.EntityByComponents(
         components::Model(),
