@@ -16,7 +16,7 @@
  */
 
 #include <gtest/gtest.h>
-#include <ignition/msgs/sdf_generator_config.pb.h>
+#include <gz/msgs/sdf_generator_config.pb.h>
 #include <sstream>
 #include <tinyxml2.h>
 
@@ -38,23 +38,23 @@
 #include <sdf/Visual.hh>
 #include <sdf/World.hh>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/math/Pose3.hh>
-#include <ignition/transport/Node.hh>
-#include <ignition/utilities/ExtraTestMacros.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Util.hh>
+#include <gz/math/Pose3.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utilities/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/test_config.hh"
 
 #include "helpers/UniqueTestDirectoryEnv.hh"
 #include "plugins/MockSystem.hh"
 #include "../helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 
 /////////////////////////////////////////////////
 class SdfGeneratorFixture : public InternalFixture<::testing::Test>
@@ -87,7 +87,9 @@ class SdfGeneratorFixture : public InternalFixture<::testing::Test>
 };
 
 /////////////////////////////////////////////////
-TEST_F(SdfGeneratorFixture, WorldWithModelsSpawnedAfterLoad)
+// See https://github.com/ignitionrobotics/ign-gazebo/issues/1175
+TEST_F(SdfGeneratorFixture,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(WorldWithModelsSpawnedAfterLoad))
 {
   this->LoadWorld("test/worlds/save_world.sdf");
 
@@ -113,7 +115,7 @@ TEST_F(SdfGeneratorFixture, WorldWithModelsSpawnedAfterLoad)
   // This has to be different from the backpack in order to test SDFormat
   // generation for a Fuel URI that was not known when simulation started.
   const std::string groundPlaneUri =
-      "https://fuel.ignitionrobotics.org/1.0/OpenRobotics/models/ground plane";
+      "https://fuel.gazebosim.org/1.0/OpenRobotics/models/ground plane";
 
   transport::Node node;
   {
@@ -215,7 +217,7 @@ TEST_F(SdfGeneratorFixture, WorldWithModelsSpawnedAfterLoad)
 /////////////////////////////////////////////////
 // Test segfaults on Mac at startup, possible collision with test above?
 TEST_F(SdfGeneratorFixture,
-    IGN_UTILS_TEST_DISABLED_ON_MAC(ModelSpawnedWithNewName))
+    IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(ModelSpawnedWithNewName))
 {
   this->LoadWorld("test/worlds/save_world.sdf");
 
