@@ -17,27 +17,35 @@
 
 #include <gtest/gtest.h>
 #include <sdf/sdf.hh>
-#include <ignition/common/Filesystem.hh>
-#include <ignition/fuel_tools.hh>
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/test_config.hh"  // NOLINT(build/include)
+#include <gz/common/Filesystem.hh>
+#include <gz/fuel_tools.hh>
+#include <gz/utils/ExtraTestMacros.hh>
+#include "gz/sim/Server.hh"
+#include "gz/sim/test_config.hh"  // NOLINT(build/include)
 
-using namespace ignition;
-using namespace gazebo;
+#include "../helpers/EnvTestFixture.hh"
+
+using namespace gz;
+using namespace gz::sim;
+
+class SdfInclude : public InternalFixture<::testing::Test>
+{
+};
 
 /////////////////////////////////////////////////
-TEST(SdfInclude, DownloadFromFuel)
+// See https://github.com/gazebosim/gz-sim/issues/1175
+TEST_F(SdfInclude, IGN_UTILS_TEST_DISABLED_ON_WIN32(DownloadFromFuel))
 {
   std::string path = common::cwd() + "/test_cache";
 
   // Configure the gazebo server, which will cause a model to be downloaded.
-  gazebo::ServerConfig serverConfig;
+  ServerConfig serverConfig;
   serverConfig.SetResourceCache(path);
   serverConfig.SetSdfFile(std::string(PROJECT_SOURCE_PATH) +
     "/test/worlds/include.sdf");
-  gazebo::Server server(serverConfig);
+  Server server(serverConfig);
 
   EXPECT_TRUE(common::exists(path +
-        "/fuel.ignitionrobotics.org/openrobotics/models/ground plane" +
+        "/fuel.gazebosim.org/openrobotics/models/ground plane" +
         "/1/model.sdf"));
 }
