@@ -17,29 +17,30 @@
 
 #include <gtest/gtest.h>
 
-#include <ignition/msgs/empty.pb.h>
-#include <ignition/msgs/vector3d.pb.h>
-#include <ignition/msgs/pose.pb.h>
+#include <gz/msgs/empty.pb.h>
+#include <gz/msgs/vector3d.pb.h>
+#include <gz/msgs/pose.pb.h>
 
 #include <sdf/Root.hh>
 #include <sdf/World.hh>
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Util.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Util.hh>
+#include <gz/transport/Node.hh>
+#include <gz/utils/ExtraTestMacros.hh>
 
-#include "ignition/gazebo/Server.hh"
-#include "ignition/gazebo/SystemLoader.hh"
-#include "ignition/gazebo/components/Model.hh"
-#include "ignition/gazebo/components/Name.hh"
-#include "ignition/gazebo/components/Pose.hh"
-#include "ignition/gazebo/test_config.hh"
+#include "gz/sim/Server.hh"
+#include "gz/sim/SystemLoader.hh"
+#include "gz/sim/components/Model.hh"
+#include "gz/sim/components/Name.hh"
+#include "gz/sim/components/Pose.hh"
+#include "gz/sim/test_config.hh"
 
 #include "plugins/MockSystem.hh"
 #include "../helpers/EnvTestFixture.hh"
 
-using namespace ignition;
-using namespace gazebo;
+using namespace gz;
+using namespace gz::sim;
 using namespace std::chrono_literals;
 
 class TriggeredPublisherTest : public InternalFixture<::testing::Test>
@@ -90,7 +91,9 @@ bool waitUntil(int _timeoutMs, Pred _pred)
 /////////////////////////////////////////////////
 /// Check that empty message types do not need any data to be specified in the
 /// configuration
-TEST_F(TriggeredPublisherTest, EmptyInputEmptyOutput)
+// See https://github.com/gazebo/gz-sim/issues/1175
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(EmptyInputEmptyOutput))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Empty>("/in_0");
@@ -114,7 +117,8 @@ TEST_F(TriggeredPublisherTest, EmptyInputEmptyOutput)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, WrongInputMessageTypeDoesNotMatch)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(WrongInputMessageTypeDoesNotMatch))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Boolean>("/in_0");
@@ -137,7 +141,8 @@ TEST_F(TriggeredPublisherTest, WrongInputMessageTypeDoesNotMatch)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, InputMessagesTriggerOutputs)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(InputMessagesTriggerOutputs))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Empty>("/in_1");
@@ -162,7 +167,8 @@ TEST_F(TriggeredPublisherTest, InputMessagesTriggerOutputs)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, MultipleOutputsForOneInput)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(MultipleOutputsForOneInput))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Empty>("/in_2");
@@ -207,7 +213,8 @@ TEST_F(TriggeredPublisherTest, MultipleOutputsForOneInput)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, ExactMatchBooleanInputs)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(ExactMatchBooleanInputs))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Boolean>("/in_3");
@@ -240,7 +247,8 @@ TEST_F(TriggeredPublisherTest, ExactMatchBooleanInputs)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, MatchersWithLogicTypeAttribute)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(MatchersWithLogicTypeAttribute))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Int32>("/in_4");
@@ -276,7 +284,8 @@ TEST_F(TriggeredPublisherTest, MatchersWithLogicTypeAttribute)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, MultipleMatchersAreAnded)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(MultipleMatchersAreAnded))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Int32>("/in_5");
@@ -301,7 +310,7 @@ TEST_F(TriggeredPublisherTest, MultipleMatchersAreAnded)
 }
 
 /////////////////////////////////////////////////
-TEST_F(TriggeredPublisherTest, FieldMatchers)
+TEST_F(TriggeredPublisherTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(FieldMatchers))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Vector2d>("/in_6");
@@ -340,7 +349,9 @@ TEST_F(TriggeredPublisherTest, FieldMatchers)
 /////////////////////////////////////////////////
 /// Tests that if the specified field is a repeated field, a partial match is
 /// used when comparing against the input.
-TEST_F(TriggeredPublisherTest, FieldMatchersWithRepeatedFieldsUsePartialMatches)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(
+           FieldMatchersWithRepeatedFieldsUsePartialMatches))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Pose>("/in_7");
@@ -377,7 +388,8 @@ TEST_F(TriggeredPublisherTest, FieldMatchersWithRepeatedFieldsUsePartialMatches)
   EXPECT_EQ(1u, recvCount);
 }
 
-TEST_F(TriggeredPublisherTest, WrongInputWhenRepeatedSubFieldExpected)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(WrongInputWhenRepeatedSubFieldExpected))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Empty>("/in_7");
@@ -406,8 +418,8 @@ TEST_F(TriggeredPublisherTest, WrongInputWhenRepeatedSubFieldExpected)
 /// fields by specifying the containing field of the repeated field in the
 /// "field" attribute and setting the desired values of the repeated field in
 /// the value of the <match> tag.
-TEST_F(TriggeredPublisherTest,
-       FieldMatchersWithRepeatedFieldsInValueUseFullMatches)
+TEST_F(TriggeredPublisherTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(
+       FieldMatchersWithRepeatedFieldsInValueUseFullMatches))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Pose>("/in_8");
@@ -448,8 +460,8 @@ TEST_F(TriggeredPublisherTest,
 /// Tests that full matchers can be used with repeated fields by specifying the
 /// desired values of the repeated field in the value of the <match> tag. The
 /// message created from the value of <match> must be a full match of the input.
-TEST_F(TriggeredPublisherTest,
-       FullMatchersWithRepeatedFieldsInValueUseFullMatches)
+TEST_F(TriggeredPublisherTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(
+       FullMatchersWithRepeatedFieldsInValueUseFullMatches))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Int32_V>("/in_9");
@@ -476,7 +488,8 @@ TEST_F(TriggeredPublisherTest,
   EXPECT_EQ(1u, recvCount);
 }
 
-TEST_F(TriggeredPublisherTest, FullMatchersAcceptToleranceParam)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(FullMatchersAcceptToleranceParam))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Float>("/in_10");
@@ -503,7 +516,8 @@ TEST_F(TriggeredPublisherTest, FullMatchersAcceptToleranceParam)
   EXPECT_EQ(3u, recvCount);
 }
 
-TEST_F(TriggeredPublisherTest, FieldMatchersAcceptToleranceParam)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(FieldMatchersAcceptToleranceParam))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Pose>("/in_11");
@@ -532,7 +546,8 @@ TEST_F(TriggeredPublisherTest, FieldMatchersAcceptToleranceParam)
   EXPECT_EQ(3u, recvCount);
 }
 
-TEST_F(TriggeredPublisherTest, SubfieldsOfRepeatedFieldsNotSupported)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(SubfieldsOfRepeatedFieldsNotSupported))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Header>("/in_12");
@@ -562,7 +577,7 @@ TEST_F(TriggeredPublisherTest, SubfieldsOfRepeatedFieldsNotSupported)
   EXPECT_EQ(0u, recvCount);
 }
 
-TEST_F(TriggeredPublisherTest, TriggerDelay)
+TEST_F(TriggeredPublisherTest, IGN_UTILS_TEST_DISABLED_ON_WIN32(TriggerDelay))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Empty>("/in_13");
@@ -597,7 +612,8 @@ TEST_F(TriggeredPublisherTest, TriggerDelay)
   EXPECT_EQ(pubCount, recvCount);
 }
 
-TEST_F(TriggeredPublisherTest, WrongInputWhenRepeatedFieldExpected)
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(WrongInputWhenRepeatedFieldExpected))
 {
   transport::Node node;
   auto inputPub = node.Advertise<msgs::Int32>("/invalid_topic");
@@ -621,3 +637,272 @@ TEST_F(TriggeredPublisherTest, WrongInputWhenRepeatedFieldExpected)
 
   EXPECT_EQ(0u, recvCount);
 }
+
+/////////////////////////////////////////////////
+/// Test for invalid service name. A service, `/srv-dummy-test` is advertised
+/// and the callback is also provided in this test. Everytime an input msg is
+/// published to `/in_14` topic, triggered_publisher plugin will call the
+/// service `srv-test`, specified in the test/worlds/triggered_publisher.sdf.
+/// However, since the two service names do not match, the callback provided in
+/// this test will not be invoked. Therefore, the pubCount, which is set to 10,
+/// will not equal to recvCount. The recvCount will be 0, since the callback
+/// isn't invoked.
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(InvalidServiceName))
+{
+  transport::Node node;
+  auto inputPub = node.Advertise<msgs::Empty>("/in_14");
+  std::atomic<std::size_t> recvCount{0};
+
+  auto srvEchoCb = std::function<bool(const msgs::StringMsg &,
+      msgs::StringMsg &)>(
+      [&recvCount](const auto &req, auto &)
+      {
+        EXPECT_EQ(req.data(), "test");
+        if (req.data() == "test")
+        {
+          ++recvCount;
+          return true;
+        }
+        return false;
+      });
+
+  // Advertise a dummy service
+  std::string service = "/srv-dummy-test";
+  node.Advertise(service, srvEchoCb);
+
+  const std::size_t pubCount{10};
+  for (std::size_t i = 0; i < pubCount; ++i)
+  {
+    EXPECT_TRUE(inputPub.Publish(msgs::Empty()));
+    IGN_SLEEP_MS(100);
+  }
+
+  waitUntil(5000, [&]{return recvCount == 0u;});
+  EXPECT_EQ(recvCount, 0u);
+}
+
+/////////////////////////////////////////////////
+/// Test for triggering a service call in response to an input msg. A service,
+/// `srv-test` is advertised and the callback is also provided in this test.
+/// Everytime an input msg is published to `/in_14` topic, triggered_publisher
+/// plugin will call the service `/srv-test`, specified in the test/worlds/
+/// triggered_publisher.sdf. This time, the name of the services match. By
+/// publishing input msg 10 times, the service callback will also be invoked 10
+/// times. The `pubCount` is set to 10 and recvCount is increased everytime
+/// request data matches the string "test" inside the service callback. For a
+/// successful test, the pubCount will equal to recvCount.
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(InputMessagesTriggerServices))
+{
+  transport::Node node;
+  auto inputPub = node.Advertise<msgs::Empty>("/in_14");
+  std::atomic<std::size_t> recvCount{0};
+
+  auto srvEchoCb = std::function<bool(const msgs::StringMsg &,
+      msgs::StringMsg &)>(
+      [&recvCount](const auto &req, auto &)
+        {
+          EXPECT_EQ(req.data(), "test");
+          if (req.data() == "test")
+          {
+            ++recvCount;
+            return true;
+          }
+          return false;
+        });
+
+  std::string service = "/srv-test";
+  node.Advertise(service, srvEchoCb);
+
+  const std::size_t pubCount{10};
+  for (std::size_t i = 0; i < pubCount; ++i)
+  {
+    EXPECT_TRUE(inputPub.Publish(msgs::Empty()));
+    IGN_SLEEP_MS(100);
+  }
+
+  waitUntil(5000, [&]{return pubCount == recvCount;});
+  EXPECT_EQ(pubCount, recvCount);
+}
+
+/////////////////////////////////////////////////
+/// Test for triggering multiple services (in sequence) in response to an input
+/// msg by publishing 10 times. Two services, `srv-test-0` and `srv-test-1` are
+/// specified in the test/worlds/triggered_publisher.sdf. Everytime an input msg
+/// is published, triggered_publisher will call the service and invoke the
+/// callback. std::vector is passed as a reference and will be populated with
+/// the request message, which will be a boolean value of `true`. If successful,
+/// `recvMsg0` and `recvMsg1` vectors should both have a size of 10 with all
+/// true boolean values.
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(MultipleServiceForOneInput))
+{
+  transport::Node node;
+  auto inputPub = node.Advertise<msgs::Empty>("/in_15");
+  std::mutex recvMsgMutex;
+  std::vector<bool> recvMsgs0;
+  std::vector<bool> recvMsgs1;
+  auto cbCreator = [&recvMsgMutex](std::vector<bool> &_msgVector)
+  {
+    return std::function<bool(const msgs::Boolean &, msgs::Boolean &)>(
+        [&_msgVector, &recvMsgMutex](const auto &req, auto &)
+        {
+          std::lock_guard<std::mutex> lock(recvMsgMutex);
+          if (req.data())
+          {
+            _msgVector.push_back(req.data());
+            return true;
+          }
+          return false;
+        });
+  };
+
+  auto msgCb0 = cbCreator(recvMsgs0);
+  auto msgCb1 = cbCreator(recvMsgs1);
+
+  // Advertise two dummy services
+  node.Advertise("/srv-test-0", msgCb0);
+  node.Advertise("/srv-test-1", msgCb1);
+
+  const int pubCount{10};
+  for (int i = 0; i < pubCount; ++i)
+  {
+    EXPECT_TRUE(inputPub.Publish(msgs::Empty()));
+    IGN_SLEEP_MS(100);
+  }
+
+  waitUntil(5000, [&]
+      {
+        std::lock_guard<std::mutex> lock(recvMsgMutex);
+        return static_cast<std::size_t>(pubCount) == recvMsgs0.size() &&
+               static_cast<std::size_t>(pubCount) == recvMsgs1.size();
+      });
+
+  EXPECT_EQ(static_cast<std::size_t>(pubCount), recvMsgs0.size());
+  EXPECT_EQ(static_cast<std::size_t>(pubCount), recvMsgs1.size());
+
+  // The plugin has two outputs. We expect 10 messages in each output topic
+  EXPECT_EQ(pubCount, std::count(recvMsgs0.begin(), recvMsgs0.end(), true));
+  EXPECT_EQ(pubCount, std::count(recvMsgs1.begin(), recvMsgs1.end(), true));
+}
+
+/////////////////////////////////////////////////
+/// Test for triggering a service call with incorrect request type or reply
+/// type specified in test/worlds/triggered_publisher.sdf. `InvalidReqType` and
+/// `InvalidRepType` do not exist. Hence, the callback will never be invoked and
+/// the recvCount will be 0.
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(WrongRequestOrResponseType))
+{
+  transport::Node node;
+  auto inputPub = node.Advertise<msgs::Empty>("/in_16");
+  std::atomic<std::size_t> recvCount{0};
+
+  auto srvEchoCb = std::function<bool(const msgs::StringMsg &,
+      msgs::StringMsg &)>(
+      [&recvCount](const auto &req, auto &)
+        {
+          EXPECT_EQ(req.data(), "test");
+          if (req.data() == "test")
+          {
+            ++recvCount;
+            return true;
+          }
+          return false;
+        });
+
+  // Advertise a dummy service
+  std::string service = "/srv-test";
+  node.Advertise(service, srvEchoCb);
+
+  const std::size_t pubCount{10};
+  for (std::size_t i = 0; i < pubCount; ++i)
+  {
+    EXPECT_TRUE(inputPub.Publish(msgs::Empty()));
+    IGN_SLEEP_MS(100);
+  }
+
+  waitUntil(5000, [&]{return recvCount == 0u;});
+  EXPECT_EQ(0u, recvCount);
+}
+
+/////////////////////////////////////////////////
+/// Test for triggering a service call with different request (Boolean) and
+/// reply type (StringMsg). Check `InputMessagesTriggerServices` test  for more
+/// details on how the test works. This test is very similar except that it has
+/// different request and reply type.
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(BooleanReqStringMsgRep))
+{
+  transport::Node node;
+  auto inputPub = node.Advertise<msgs::Empty>("/in_18");
+  std::atomic<std::size_t> recvCount{0};
+
+  auto srvEchoCb = std::function<bool(const msgs::Boolean &,
+      msgs::StringMsg &)>(
+      [&recvCount](const auto &req, auto &)
+        {
+          EXPECT_EQ(req.data(), true);
+          if (req.data() == true)
+          {
+            ++recvCount;
+            return true;
+          }
+          return false;
+        });
+
+  // Advertise a dummy service
+  std::string service = "/srv-diff-type-0";
+  node.Advertise(service, srvEchoCb);
+
+  const std::size_t pubCount{10};
+  for (std::size_t i = 0; i < pubCount; ++i)
+  {
+    EXPECT_TRUE(inputPub.Publish(msgs::Empty()));
+    IGN_SLEEP_MS(100);
+  }
+
+  waitUntil(5000, [&]{return pubCount == recvCount;});
+  EXPECT_EQ(pubCount, recvCount);
+}
+
+/////////////////////////////////////////////////
+/// Test for triggering a service call with different request (StringMsg) and
+/// reply type (Boolean). Check `InputMessagesTriggerServices` test  for more
+/// details on how the test works. This test is very similar except that it has
+/// different request and reply type.
+TEST_F(TriggeredPublisherTest,
+       IGN_UTILS_TEST_DISABLED_ON_WIN32(StringMsgReqBooleanRep))
+{
+  transport::Node node;
+  auto inputPub = node.Advertise<msgs::Empty>("/in_19");
+  std::atomic<std::size_t> recvCount{0};
+
+  auto srvEchoCb = std::function<bool(const msgs::StringMsg &,
+      msgs::Boolean &)>(
+      [&recvCount](const auto &req, auto &)
+        {
+          EXPECT_EQ(req.data(), "test");
+          if (req.data() == "test")
+          {
+            ++recvCount;
+            return true;
+          }
+          return false;
+        });
+
+  // Advertise a dummy service
+  std::string service = "/srv-diff-type-1";
+  node.Advertise(service, srvEchoCb);
+
+  const std::size_t pubCount{10};
+  for (std::size_t i = 0; i < pubCount; ++i)
+  {
+    EXPECT_TRUE(inputPub.Publish(msgs::Empty()));
+    IGN_SLEEP_MS(100);
+  }
+
+  waitUntil(5000, [&]{return pubCount == recvCount;});
+  EXPECT_EQ(recvCount, recvCount);
+}
